/*
*******************************************************************************
  Copyright (C), 2010-2012, timll Tech. Co., Ltd.
  FileName      : STM32_F105-07_F2xx_USB-Host-Device_Lib_V2.0.0/Project/USB_Device_Examples/DFU/main.c
  Author        : lichy       
  Version       : 1.0.0     
  Date          : 2011/10/28
  Description   : This Demo presents the implementation of a device firmware upgrade 
                  (DFU) capability in the STM32F2xx and STM32F105/7 devices. It follows 
                  the DFU class specification defined by the USB Implementers Forum for 
                  reprogramming an application through USB-FS-Device.  
                  The DFU principle is particularly well suited to USB-FS-Device applications 
                  that need to be reprogrammed in the field.
  Function List : 
  History       :
  <author>      : lichy       
  <time>       	: 2011/10/28
  <version>     : 1.0.0 	
  <desc>        : build this moudle				 
*******************************************************************************
*/ 

/* Includes ------------------------------------------------------------------*/ 
#include  <stdio.h>

#include  "usbd_dfu_core.h"
#include  "usbd_usr.h"
#include  "usbd_desc.h"
#include	"ra8870.h"
#include	"i2C_ee.h"
#include    "spi.h"

/** @addtogroup STM32_USB_OTG_DEVICE_LIBRARY
  * @{
  */


/** @defgroup APP_DFU 
  * @brief Mass storage application module
  * @{
  */ 

/** @defgroup APP_DFU_Private_TypesDefinitions
  * @{
  */ 
/**
  * @}
  */ 


/** @defgroup APP_DFU_Private_Defines
  * @{
  */ 

/**
  * @}
  */ 


/** @defgroup APP_DFU_Private_Macros
  * @{
  */ 
/**
  * @}
  */ 


/** @defgroup APP_DFU_Private_Variables
  * @{
  */ 
  
#ifdef USB_OTG_HS_INTERNAL_DMA_ENABLED
  #if defined ( __ICCARM__ ) /*!< IAR Compiler */
    #pragma data_alignment=4   
  #endif
#endif /* USB_OTG_HS_INTERNAL_DMA_ENABLED */

__ALIGN_BEGIN USB_OTG_CORE_HANDLE    USB_OTG_dev __ALIGN_END ;


pFunction Jump_To_Application;
uint32_t JumpAddress;





/**
  * @}
  */ 


/** @defgroup APP_DFU_Private_FunctionPrototypes
  * @{
  */ 
/**
  * @}
  */ 
#if DUT_DEVICE == PVS

#define ADC_CCR_ADDRESS    ((uint32_t)0x40012308)
__IO uint16_t ADCDualConvertedValue[4];
float buf,VFDfreq;
float YnADCDualConvertedValue[3] = {0,0,0};
float XnADCDualConvertedValue[3] = {0,0,0};
ADC_CommonInitTypeDef ADC_CommonInitStructure;



/**
  * @brief Configure ADC Channels 10, 11, 12 pins as analog inputs
  * @param  None
  * @retval None
  */
void GPIO_Config(void)
{
  GPIO_InitTypeDef GPIO_InitStructure;
  /* ADC Channel 10 -> PC0
     ADC Channel 11 -> PC1
	 ADC Channel 11 -> PC2
  */
  RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOC, ENABLE);
  GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_0 | GPIO_Pin_1 | GPIO_Pin_2 ;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AN;
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL ;
  GPIO_Init(GPIOC, &GPIO_InitStructure);

//  GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_0 | GPIO_Pin_1 ;
//  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN;
//  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
//  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_UP;
//  GPIO_Init(GPIOC, &GPIO_InitStructure);
}


void initAdc1(void)
{
  ADC_InitTypeDef ADC_InitStructure;
  /* Enable peripheral clocks *************************************************/
  RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOC, ENABLE);
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_ADC1|RCC_APB2Periph_ADC2, ENABLE);
  /* Configure ADC Channel10, 11, 12 pin as analog input */
  GPIO_Config();

  ADC_InitStructure.ADC_Resolution = ADC_Resolution_12b;
  ADC_InitStructure.ADC_ScanConvMode = DISABLE;
  ADC_InitStructure.ADC_ContinuousConvMode = DISABLE;
  ADC_InitStructure.ADC_ExternalTrigConvEdge = ADC_ExternalTrigConvEdge_None;
  ADC_InitStructure.ADC_DataAlign = ADC_DataAlign_Right;
  ADC_InitStructure.ADC_NbrOfConversion = 1;
  ADC_Init(ADC1, &ADC_InitStructure);

//  ADC_RegularChannelConfig(ADC1, ADC_Channel_10, 1, ADC_SampleTime_3Cycles);

  /* Enable ADC1 */
  ADC_Cmd(ADC1, ENABLE);

//  VFDflag = 1;//}lVFDAD
}

void getAdCh(uint8_t ch)
{
  ADC_RegularChannelConfig(ADC1, ADC_Channel_12, 1, ADC_SampleTime_3Cycles);
  /* Enable ADC1 */
  ADC_SoftwareStartConv(ADC1);

  while (ADC_GetFlagStatus(ADC1,ADC_FLAG_EOC) != SET);
  if (ADC_GetFlagStatus(ADC1,ADC_FLAG_OVR)  == SET)
  {
	  ADC_ClearFlag(ADC1,ADC_FLAG_OVR);				// over run
	  ADC_ClearFlag(ADC1,ADC_FLAG_EOC);
	  return;
  }
  ADC_ClearFlag(ADC1,ADC_FLAG_EOC);
  ADCDualConvertedValue[ch] = ADC_GetConversionValue(ADC1);
}




void HVVoltage(void)
{
	/*  Bz A/D íw */
		getAdCh(2);
		XnADCDualConvertedValue[2] = ADCDualConvertedValue[2];
		buf = ((YnADCDualConvertedValue[2] * (512 - 1)) + XnADCDualConvertedValue[2])/512;
		YnADCDualConvertedValue[2] = buf;
}




/**
  * @brief  Configure the TIM8 Pins.
  * @param  None
  * @retval None
  */
void TIM8_CH1_CH1N_PWM_Config(void)
{
  GPIO_InitTypeDef GPIO_InitStructure;
  TIM_BDTRInitTypeDef TIM_BDTRInitStructure;
  TIM_TimeBaseInitTypeDef  	TIM_TimeBaseStructure;
  TIM_OCInitTypeDef  			TIM_OCInitStructure;

  
  /* TIM8 clock enable */
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_TIM8, ENABLE);

  /* GPIOC clock enable */
  RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOA | RCC_AHB1Periph_GPIOC, ENABLE);
   
  /* GPIOC Configuration: TIM8 CH1 (PC6) */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_6;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_2MHz;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_UP ;
  GPIO_Init(GPIOC, &GPIO_InitStructure); 
    
  /* Connect TIM Channels to AF3 */
  GPIO_PinAFConfig(GPIOC, GPIO_PinSource6, GPIO_AF_TIM8);

  /* GPIOC Configuration: TIM8 CH1N (PA7) */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_7;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_2MHz;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_UP ;
  GPIO_Init(GPIOA, &GPIO_InitStructure); 
    
  /* Connect TIM Channels to AF3 */
  GPIO_PinAFConfig(GPIOA, GPIO_PinSource7, GPIO_AF_TIM8);


/*  ----------------------------------------------------------------------------
    The TIM8 is running at 1MHz: TIM8 Frequency = TIM8 counter clock /(ARR + 1)
                                                    = 1000000 / 100 = 10 KHz


*/
  /* Time Base configuration */
  TIM_TimeBaseStructure.TIM_Prescaler = (uint16_t) ((SystemCoreClock) / (VFDfreq*100)) - 1; // 22.5kHz  Futaba VFD
  TIM_TimeBaseStructure.TIM_CounterMode = TIM_CounterMode_Up;
  TIM_TimeBaseStructure.TIM_Period = 100;
  TIM_TimeBaseStructure.TIM_ClockDivision = 0;
  TIM_TimeBaseStructure.TIM_RepetitionCounter = 0;

  TIM_TimeBaseInit(TIM8, &TIM_TimeBaseStructure);

  /* Channel Configuration in PWM mode */
  TIM_OCInitStructure.TIM_OCMode = TIM_OCMode_PWM1;
  TIM_OCInitStructure.TIM_OutputState = TIM_OutputState_Enable;
  TIM_OCInitStructure.TIM_OutputNState = TIM_OutputNState_Enable;
  TIM_OCInitStructure.TIM_Pulse = 50;					 // duty 50% 
  TIM_OCInitStructure.TIM_OCPolarity = TIM_OCPolarity_High;
  TIM_OCInitStructure.TIM_OCNPolarity = TIM_OCNPolarity_High;
  TIM_OCInitStructure.TIM_OCIdleState = TIM_OCIdleState_Set;
  TIM_OCInitStructure.TIM_OCNIdleState = TIM_OCNIdleState_Set;

  TIM_OC1Init(TIM8, &TIM_OCInitStructure);

  /* Automatic Output enable, Break, dead time and lock configuration*/
  TIM_BDTRInitStructure.TIM_OSSRState = TIM_OSSRState_Disable;
  TIM_BDTRInitStructure.TIM_OSSIState = TIM_OSSIState_Disable;
  TIM_BDTRInitStructure.TIM_LOCKLevel = TIM_LOCKLevel_OFF;
  TIM_BDTRInitStructure.TIM_DeadTime = (0xE0+0);   // delay time DTS = 1/120MHz ,	 0x80 => DT=(64+DTG[5:0])xtdtg with Tdtg=2xtDTS. (64+63)*2*(1/120Mhz) = 2.1us
  TIM_BDTRInitStructure.TIM_Break = TIM_Break_Enable;	 //  0xC0 =>  DT=(32+DTG[4:0])xtdtg with Tdtg=8xtDTS . (32 +  31) * 8 * (1/120Mhz) = 4.2us
  TIM_BDTRInitStructure.TIM_BreakPolarity = TIM_BreakPolarity_High;// 0xE0 => DT=(32+DTG[4:0])xtdtg with Tdtg=16xtDTS , (32 + 31) * 16 * (1/120Mhz) = 8.4us
  TIM_BDTRInitStructure.TIM_AutomaticOutput = TIM_AutomaticOutput_Enable;

  TIM_BDTRConfig(TIM8, &TIM_BDTRInitStructure);

  TIM_CCPreloadControl(TIM8, ENABLE);

  TIM_ITConfig(TIM8, TIM_IT_COM, ENABLE);

  /* TIM8 counter enable */
  TIM_Cmd(TIM8, ENABLE);

  /* Main Output Enable */
  TIM_CtrlPWMOutputs(TIM8, ENABLE);



}
uint8_t set_vfd_too_high = 0;

void checkVFDFreq(void)
{
	if (set_vfd_too_high == 0)
	{
		uint8_t change = 0;
		if (YnADCDualConvertedValue[2]	> 2150)		//ئa P_ VFD 54VӰ {wVFDt PWM
		{
		  	TIM_CCPreloadControl(TIM8, DISABLE);
		  	TIM_ITConfig(TIM8, TIM_IT_COM, DISABLE);
		  /* TIM8 counter enable */
  			TIM_Cmd(TIM8, DISABLE);
		  /* Main Output Enable */
  			TIM_CtrlPWMOutputs(TIM8, DISABLE);
			TIM_DeInit(TIM8);
			set_vfd_too_high = 1;
			return;
		}

			if (YnADCDualConvertedValue[2]	> 2050)	// 2100  = 1.7V
			{
				VFDfreq -= 14;
				change = 1;
			}
			else if (YnADCDualConvertedValue[2]	< 1950)
			{
				VFDfreq += 14;
				change = 1;
			}
			if (VFDfreq >= 45000 )	  // too high must be protected
			{
				VFDfreq = 45000;
				change = 1;
			}
			else if (VFDfreq <= 7000)
			{
				VFDfreq = 7000;
				change = 1;
			}
			if (change == 1)
				TIM8_CH1_CH1N_PWM_Config();
	}
}





#endif



/*==================================================================================*/
/************ HUO keyboard Cinitial \ ******************************/
/*==================================================================================*/






void initializeKeyboard(void)
{
 	GPIO_InitTypeDef  			GPIO_InitStructure;
	/*********** keyboard I/O initial ****************/
#if DUT_DEVICE == LCR_4030
	
	/* GPIOB GPIOC Periph clock enable */
  	RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOB | RCC_AHB1Periph_GPIOC, ENABLE);
  	/* Configure PB0 PB1 PB2 PB5 PB6 in input pushpull mode */
  	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_0 | GPIO_Pin_1 | GPIO_Pin_2 | GPIO_Pin_5 | GPIO_Pin_6;
  	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN;
 	// GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  	GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;
  	GPIO_Init(GPIOB, &GPIO_InitStructure);


  	/* Configure PC0 PC1 PC2 PC3 PC4 PC5in input pushpull mode */
  	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_0 | GPIO_Pin_1 | GPIO_Pin_2 | GPIO_Pin_3 | GPIO_Pin_4 | GPIO_Pin_5;
  	GPIO_InitStructure.GPIO_Mode =  GPIO_Mode_OUT;
  	GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_100MHz;
  	GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_UP;
  	GPIO_Init(GPIOC, &GPIO_InitStructure);

#elif DUT_DEVICE == PVS
//	uint8_t i;
	VFDfreq = 8000; // VFD 8khz
	initAdc1();
	sVFD_Init();
  	RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOA | RCC_AHB1Periph_GPIOC | RCC_AHB1Periph_GPIOE | RCC_AHB1Periph_GPIOD, ENABLE);
  	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_8;	  // SPI3_CS
  	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;
  	GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_2MHz;
  	GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;
  	GPIO_Init(GPIOC, &GPIO_InitStructure);

  	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_10|GPIO_Pin_4 | GPIO_Pin_5;	// BEEP/* DAC channel 1 & 2 (DAC_OUT1 = PA.4)(DAC_OUT2 = PA.5) configuration */
  	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;
  	GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_2MHz;
  	GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_DOWN;//GPIO_PuPd_NOPULL;
  	GPIO_Init(GPIOA, &GPIO_InitStructure);


    GPIO_ResetBits(GPIOA, GPIO_Pin_5);	// DAC
	GPIO_ResetBits(GPIOA, GPIO_Pin_4);	// DAC
	GPIO_ResetBits(GPIOA, GPIO_Pin_10);	// BEEP = 0

//	GPIO_PinLockConfig(GPIOA, GPIO_Pin_10|GPIO_Pin_4 | GPIO_Pin_5);

    VFD_SPI_CS_HIGH;    				// SPI_CS = 1
	initializeVFD();
	delay5us(1000);
	dispVFD48((void *)displayBuffer);
  	VFD_SPI_CS_LOW;  					// SPI_CS = 0
	sVFD_SendByte(0x85);			    // Clear sign
	sVFD_SendByte((uint8_t)(0));
	sVFD_SendByte((uint8_t)(0));
	sVFD_SendByte((uint8_t)(0));
	sVFD_SendByte((uint8_t)(0));
    VFD_SPI_CS_HIGH;  
//	TIM8_CH1_CH1N_PWM_Config(); 


	keyCode = getKey();
	
#endif
}

#define OneBitSet(i)			((i) && (((i) & ((i)-1)) == 0))		/* u@bit  1  TRUE */
#define KEY_OUT_PORT	GPIOC
#define KEY_IN_PORT		GPIOB
void keyDelay(uint8_t i)
{
	for( ; i > 0 ;i--);
}


uint8_t checkPressed(uint8_t keyId)
{
	uint8_t row,col,data =0;
	uint16_t keyInData = 0x0000;
	col = keyId & 0x0f;
	row = keyId & 0xf0;
	switch(row)
	{
		case 0x10:
			GPIO_SetBits(KEY_OUT_PORT,GPIO_Pin_0);		//KEY_OUT_PORT |= 0x01;
			break;
		case 0x20:
			GPIO_SetBits(KEY_OUT_PORT,GPIO_Pin_1);		//KEY_OUT_PORT |= 0x02;		
			break;
		case 0x30:
			GPIO_SetBits(KEY_OUT_PORT,GPIO_Pin_2);		//KEY_OUT_PORT |= 0x04;		
 			break;					
		case 0x40:
			GPIO_SetBits(KEY_OUT_PORT,GPIO_Pin_3);		//KEY_OUT_PORT |= 0x08;		
			break;					
		case 0x50:
			GPIO_SetBits(KEY_OUT_PORT,GPIO_Pin_4);		//KEY_OUT_PORT |= 0x10;		
			break;
		case 0x60:
			GPIO_SetBits(KEY_OUT_PORT,GPIO_Pin_5);		//KEY_OUT_PORT = 0x20;		
 			break;					
	}
	keyDelay(10); 
	keyInData = (GPIO_ReadInputData(KEY_IN_PORT) & 0x0067);	/* 0   PB6  PB5   0    0   PB2  PB1  PB0   ==>  0x0110 0111 */
    GPIO_ResetBits(KEY_OUT_PORT,GPIO_Pin_5|GPIO_Pin_4|GPIO_Pin_3|GPIO_Pin_2|GPIO_Pin_1|GPIO_Pin_0);
//	if (OneBitSet(keyInData))	/* u@ bit high */
	{
		keyInData <<= 1;
		keyInData >>= col;
		if (((keyInData & 0x0001) == 1))
	   		data = 1;  						// pressed 
	}
	return data;
	   
}

void TIM4_KeyScanInit(void)
{
	
	TIM_TimeBaseInitTypeDef		TIM_TimeBaseStructure;
	NVIC_InitTypeDef NVIC_InitStructure;
	RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM4, ENABLE);
  	
	/* Configure the NVIC Preemption Priority Bits */  
   	NVIC_PriorityGroupConfig(NVIC_PriorityGroup_1);
		
	NVIC_InitStructure.NVIC_IRQChannel = TIM4_IRQn;
	NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 0; // meṵ ,]n޲zUSB disconnect ,beep off 
	NVIC_InitStructure.NVIC_IRQChannelSubPriority = 0;
	NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;
	
	NVIC_Init(&NVIC_InitStructure);
	
	/* Compute the prescaler value */

	TIM_TimeBaseStructure.TIM_Period = 10;  /* (1/1Mhz) x 1000 = 100ms */ 
	TIM_TimeBaseStructure.TIM_Prescaler = (uint16_t) ((SystemCoreClock / 2) / 1000000) - 1;;/* TIM4 counter clock at 1 MHz */
	TIM_TimeBaseStructure.TIM_ClockDivision = 0;
	TIM_TimeBaseStructure.TIM_CounterMode = TIM_CounterMode_Up;
	
	TIM_TimeBaseInit(TIM4, &TIM_TimeBaseStructure);
	
	TIM_ClearFlag(TIM4, TIM_FLAG_Update);
	
	TIM_ARRPreloadConfig(TIM4, DISABLE);
	
	TIM_ITConfig(TIM4, TIM_IT_Update, ENABLE);
	TIM_Cmd(TIM4, ENABLE);
}





uint8_t dut = 0;

extern void delayMs(uint32_t time);

#define KEY_B1		0x61
#define KEY_1		0x13
#define KEY_2		0x16
#define KEY_3		0x17

/** @defgroup APP_DFU_Private_Functions
  * @{
  */ 
extern uint32_t rawKeyCode;

/**
  * @brief  Program entry point
  * @param  None
  * @retval None
  */
int main(void)
{
  /* Counter for the LED toggling delay */
    __IO uint32_t i = 0; 
  
  
  /*!< At this stage the microcontroller clock setting is already configured, 
  this is done through SystemInit() function which is called from startup
  file (startup_stm32fxxx_xx.s) before to branch to application main.
  To reconfigure the default setting of SystemInit() function, refer to
  system_stm32fxxx.c file
  */  
   
  /* Configure "DFU enter" button */
	initializeKeyboard();

  /* Check if the KEY_B1 push-button on Board is pressed */
#if DUT_DEVICE == LCR_4030
    if (checkPressed(KEY_B1) == 0)
#elif DUT_DEVICE == PVS
	if (rawKeyCode != (0x10000000 | 0x00010000) ) // SHIFT & VSET key
#endif
    { /* Test if user code is programmed starting from address 0x8004000 */
        if (((*(__IO uint32_t*)APP_DEFAULT_ADD) & 0x2FFE0000 ) == 0x20000000)
        { /* Jump to user application */
            JumpAddress = *(__IO uint32_t*) (APP_DEFAULT_ADD + 4);
            Jump_To_Application = (pFunction) JumpAddress;
    /* Initialize user application's Stack Pointer */
            __set_MSP(*(__IO uint32_t*) APP_DEFAULT_ADD);
            Jump_To_Application();
        }
    } /* Otherwise enters DFU mode to allow user to program his application */


 	/* Setup SysTick Timer for 1 msec interrupts 
 	(100ms)This interrupt is used to display the current state of the DFU core */
//	TIM4_KeyScanInit();
	SysTick_Config(SystemCoreClock / 1000);
#if DUT_DEVICE == LCR_4030
   /* LCD SRAM Initial */
	initializeFSMCSRAM();
	InitializeRa8870();
	/* Buzzer PWM driver initial */

	sEE_Init();

	delayMs(250); 
	GPIO_SetBits(GPIOC,	  GPIO_Pin_8); //  turn on TFT LCD
	printText(70,5,"BK Precision Firmware upgrade");
	printText(70,25,"Please Use Numerical Select.");
	printText(70,45,"(1)LCR 4030");
	if (((*(__IO uint32_t*)APP_DEFAULT_ADD) & 0x2FFE0000 ) == 0x20000000)
	    printText(170,45,"(2)MB   (3)GPIB/LAN");
	while(1)
	{
		if (checkPressed(KEY_1) == 1)
		{
    		USBD_Init(&USB_OTG_dev,	USB_OTG_FS_CORE_ID,	&USR_desc, &DFU_cb,	&USR_cb);
			printText(170,45,"                    ");
			break;
		}
		else if (checkPressed(KEY_2) == 1)
		{
			if (((*(__IO uint32_t*)APP_DEFAULT_ADD) & 0x2FFE0000 ) == 0x20000000)
			{
			    dut = 1;
	        	eepWrite((uint8_t *)&dut, 0x1FFF, sizeof(uint8_t));
				delayMs(500);
				GPIO_ResetBits(GPIOC,	  GPIO_Pin_8); //  turn on TFT LCD
            	JumpAddress = *(__IO uint32_t*) (APP_DEFAULT_ADD + 4);
            	Jump_To_Application = (pFunction) JumpAddress;
    			/* Initialize user application's Stack Pointer */
            	__set_MSP(*(__IO uint32_t*) APP_DEFAULT_ADD);
            	Jump_To_Application();
			}
			break;
		}
		else if (checkPressed(KEY_3) == 1)
		{
			if (((*(__IO uint32_t*)APP_DEFAULT_ADD) & 0x2FFE0000 ) == 0x20000000)
			{
			    dut = 2;
	        	eepWrite((uint8_t *)&dut, 0x1FFF, sizeof(uint8_t));
				delayMs(500);
				GPIO_ResetBits(GPIOC,	  GPIO_Pin_8); //  turn on TFT LCD
            	JumpAddress = *(__IO uint32_t*) (APP_DEFAULT_ADD + 4);
            	Jump_To_Application = (pFunction) JumpAddress;
    			/* Initialize user application's Stack Pointer */
            	__set_MSP(*(__IO uint32_t*) APP_DEFAULT_ADD);
            	Jump_To_Application();

			}
			break;
		}
	}

  /* Main loop */
    while (1)
    {
    }






#elif DUT_DEVICE == PVS
  USBD_Init(&USB_OTG_dev,	USB_OTG_FS_CORE_ID,	&USR_desc, &DFU_cb,	&USR_cb);
	sprintf((void *)displayBuffer,"DFU Mode");
	while(1)
	{

	}

#endif

} 

#ifdef USE_FULL_ASSERT
/**
* @brief  assert_failed
*         Reports the name of the source file and the source line number
*         where the assert_param error has occurred.
* @param  File: pointer to the source file name
* @param  Line: assert_param error line source number
* @retval None
*/
void assert_failed(uint8_t* file, uint32_t line)
{
  /* User can add his own implementation to report the file name and line number,
  ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */
  
  /* Infinite loop */
    while (1)
    {}
}
#endif

/**
  * @}
  */ 


/**
  * @}
  */ 


/**
  * @}
  */ 

/******************* (C) COPYRIGHT 2011 STMicroelectronics *****END OF FILE****/
