
/* Includes ------------------------------------------------------------------*/
#include "spi.h"

void sVFD_LowLevel_DeInit(void);
void sVFD_LowLevel_Init(void); 

void sVFD_DeInit(void)
{
  sVFD_LowLevel_DeInit();
}

void sVFD_Init(void)
{
  SPI_InitTypeDef  SPI_InitStructure;

  sVFD_LowLevel_Init();
    
  /*!< Deselect the FLASH: Chip Select high */
  //sFLASH_CS_HIGH();

  /*!< SPI configuration */
  SPI_InitStructure.SPI_Direction = SPI_Direction_2Lines_FullDuplex;
  SPI_InitStructure.SPI_Mode = SPI_Mode_Master;
  SPI_InitStructure.SPI_DataSize = SPI_DataSize_8b;
  SPI_InitStructure.SPI_CPOL = SPI_CPOL_Low;
  SPI_InitStructure.SPI_CPHA = SPI_CPHA_2Edge;
  SPI_InitStructure.SPI_NSS = SPI_NSS_Soft;
  SPI_InitStructure.SPI_BaudRatePrescaler = SPI_BaudRatePrescaler_256;

  SPI_InitStructure.SPI_FirstBit = SPI_FirstBit_MSB;
  SPI_InitStructure.SPI_CRCPolynomial = 7;
  SPI_Init(sVFD_SPI, &SPI_InitStructure);

  /*!< Enable the sFLASH_SPI  */
  SPI_Cmd(sVFD_SPI, ENABLE);
  //SPI_SSOutputCmd(sVFD_SPI, ENABLE);
}


/**
  * @brief  Reads a byte from the SPI Flash.
  * @note   This function must be used only if the Start_Read_Sequence function
  *         has been previously called.
  * @param  None
  * @retval Byte Read from the SPI Flash.
  */
uint8_t sVFD_ReadByte(void)
{
  return (sVFD_SendByte(sFLASH_DUMMY_BYTE));
}

/**
  * @brief  Sends a byte through the SPI interface and return the byte received
  *         from the SPI bus.
  * @param  byte: byte to send.
  * @retval The value of the received byte.
  */
uint8_t sVFD_SendByte(uint8_t byte)
{
  /*!< Loop while DR register in not empty */
  while (SPI_I2S_GetFlagStatus(sVFD_SPI, SPI_I2S_FLAG_TXE) == RESET);

  /*!< Send byte through the SPI1 peripheral */
  SPI_I2S_SendData(sVFD_SPI, byte);

  /*!< Wait to receive a byte */
  while (SPI_I2S_GetFlagStatus(sVFD_SPI, SPI_I2S_FLAG_RXNE) == RESET);

  /*!< Return the byte read from the SPI bus */
  return SPI_I2S_ReceiveData(sVFD_SPI);
}

/**
  * @brief  Sends a Half Word through the SPI interface and return the Half Word
  *         received from the SPI bus.
  * @param  HalfWord: Half Word to send.
  * @retval The value of the received Half Word.
  */
uint16_t sVFD_SendHalfWord(uint16_t HalfWord)
{
  /*!< Loop while DR register in not emplty */
  while (SPI_I2S_GetFlagStatus(sVFD_SPI, SPI_I2S_FLAG_TXE) == RESET);

  /*!< Send Half Word through the sFLASH peripheral */
  SPI_I2S_SendData(sVFD_SPI, HalfWord);

  /*!< Wait to receive a Half Word */
  while (SPI_I2S_GetFlagStatus(sVFD_SPI, SPI_I2S_FLAG_RXNE) == RESET);

  /*!< Return the Half Word read from the SPI bus */
  return SPI_I2S_ReceiveData(sVFD_SPI);
}

/**
  * @brief  Initializes the peripherals used by the SPI FLASH driver.
  * @param  None
  * @retval None
  */
void sVFD_LowLevel_Init(void)
{
  GPIO_InitTypeDef GPIO_InitStructure;

  /*!< Enable the SPI clock */
  sVFD_SPI_CLK_INIT(sVFD_SPI_CLK, ENABLE);

  /*!< Enable GPIO clocks */
  RCC_AHB1PeriphClockCmd(sVFD_SPI_SCK_GPIO_CLK | sVFD_SPI_MISO_GPIO_CLK | 
                         sVFD_SPI_MOSI_GPIO_CLK | sVFD_SPI_NSS_GPIO_CLK, ENABLE);
  
  /*!< SPI pins configuration *************************************************/

  /*!< Connect SPI pins to AF5 */  
//  GPIO_PinAFConfig(sVFD_SPI_NSS_GPIO_PORT, sVFD_SPI_NSS_SOURCE, sVFD_SPI_NSS_AF);
  GPIO_PinAFConfig(sVFD_SPI_SCK_GPIO_PORT, sVFD_SPI_SCK_SOURCE, sVFD_SPI_SCK_AF);
  GPIO_PinAFConfig(sVFD_SPI_MISO_GPIO_PORT, sVFD_SPI_MISO_SOURCE, sVFD_SPI_MISO_AF);
  GPIO_PinAFConfig(sVFD_SPI_MOSI_GPIO_PORT, sVFD_SPI_MOSI_SOURCE, sVFD_SPI_MOSI_AF);

  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  GPIO_InitStructure.GPIO_PuPd  = GPIO_PuPd_DOWN;
  /*!< SPI SCK pin configuration */

  /*!< SPI NSS pin configuration */
//  GPIO_InitStructure.GPIO_Pin = sVFD_SPI_NSS_PIN;
//  GPIO_Init(sVFD_SPI_NSS_GPIO_PORT, &GPIO_InitStructure);
        
  /*!< SPI SCK pin configuration */
  GPIO_InitStructure.GPIO_Pin = sVFD_SPI_SCK_PIN;
  GPIO_Init(sVFD_SPI_SCK_GPIO_PORT, &GPIO_InitStructure);

  /*!< SPI MOSI pin configuration */
  GPIO_InitStructure.GPIO_Pin =  sVFD_SPI_MOSI_PIN;
  GPIO_Init(sVFD_SPI_MOSI_GPIO_PORT, &GPIO_InitStructure);

  /*!< SPI MISO pin configuration */
  GPIO_InitStructure.GPIO_Pin =  sVFD_SPI_MISO_PIN;
  GPIO_Init(sVFD_SPI_MISO_GPIO_PORT, &GPIO_InitStructure);

  /*!< Configure sFLASH Card CS pin in output pushpull mode ********************/
//  GPIO_InitStructure.GPIO_Pin = sFLASH_CS_PIN;
//  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;
//  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
//  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
//  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;
//  GPIO_Init(sFLASH_CS_GPIO_PORT, &GPIO_InitStructure);
}

/**
  * @brief  DeInitializes the peripherals used by the SPI FLASH driver.
  * @param  None
  * @retval None
  */
void sVFD_LowLevel_DeInit(void)
{
  GPIO_InitTypeDef GPIO_InitStructure;

  /*!< Disable the sFLASH_SPI  ************************************************/
  SPI_Cmd(sVFD_SPI, DISABLE);
  
  /*!< DeInitializes the sFLASH_SPI *******************************************/
  SPI_I2S_DeInit(sVFD_SPI);
  
  /*!< sFLASH_SPI Periph clock disable ****************************************/
  sVFD_SPI_CLK_INIT(sVFD_SPI_CLK, DISABLE);
      
  /*!< Configure all pins used by the SPI as input floating *******************/
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN;
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;

//  GPIO_InitStructure.GPIO_Pin = sVFD_SPI_NSS_PIN;
//  GPIO_Init(sVFD_SPI_NSS_GPIO_PORT, &GPIO_InitStructure);

  GPIO_InitStructure.GPIO_Pin = sVFD_SPI_SCK_PIN;
  GPIO_Init(sVFD_SPI_SCK_GPIO_PORT, &GPIO_InitStructure);

  GPIO_InitStructure.GPIO_Pin = sVFD_SPI_MISO_PIN;
  GPIO_Init(sVFD_SPI_MISO_GPIO_PORT, &GPIO_InitStructure);

  GPIO_InitStructure.GPIO_Pin = sVFD_SPI_MOSI_PIN;
  GPIO_Init(sVFD_SPI_MOSI_GPIO_PORT, &GPIO_InitStructure);

//  GPIO_InitStructure.GPIO_Pin = sFLASH_CS_PIN;
//  GPIO_Init(sFLASH_CS_GPIO_PORT, &GPIO_InitStructure);
}

/**
  * @}
  */

/**
  * @}
  */

/******************* (C) COPYRIGHT 2011 STMicroelectronics *****END OF FILE****/
