/**
  ******************************************************************************
  * @file    spi_flash.h
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    18-April-2011
  * @brief   This file contains all the functions prototypes for the spi_flash
  *          firmware driver.
  ******************************************************************************
  * @attention
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2011 STMicroelectronics</center></h2>
  ******************************************************************************  
  */ 

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __SPI_FLASH_H
#define __SPI_FLASH_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "stm32f2xx.h"

/* Exported types ------------------------------------------------------------*/
/* Exported constants --------------------------------------------------------*/

/* M25P SPI Flash supported commands */  
#define sFLASH_CMD_WRITE          0x02  /* Write to Memory instruction */
#define sFLASH_CMD_WRSR           0x01  /* Write Status Register instruction */
#define sFLASH_CMD_WREN           0x06  /* Write enable instruction */
#define sFLASH_CMD_READ           0x03  /* Read from Memory instruction */
#define sFLASH_CMD_RDSR           0x05  /* Read Status Register instruction  */
#define sFLASH_CMD_RDID           0x9F  /* Read identification */
#define sFLASH_CMD_SE             0xD8  /* Sector Erase instruction */
#define sFLASH_CMD_BE             0xC7  /* Bulk Erase instruction */

#define sFLASH_WIP_FLAG           0x01  /* Write In Progress (WIP) flag */

#define sFLASH_DUMMY_BYTE         0xFF
#define sFLASH_SPI_PAGESIZE       0x100

#define sFLASH_M25P128_ID         0x202018
#define sFLASH_M25P64_ID          0x202017
  
/* VFD FLASH SPI Interface pins  */  
#define sVFD_SPI                             SPI3
#define sVFD_SPI_CLK                         RCC_APB1Periph_SPI3
#define sVFD_SPI_CLK_INIT                    RCC_APB1PeriphClockCmd

#define sVFD_SPI_SCK_PIN                     GPIO_Pin_10
#define sVFD_SPI_SCK_GPIO_PORT               GPIOC
#define sVFD_SPI_SCK_GPIO_CLK                RCC_AHB1Periph_GPIOC
#define sVFD_SPI_SCK_SOURCE                  GPIO_PinSource10
#define sVFD_SPI_SCK_AF                      GPIO_AF_SPI3

#define sVFD_SPI_MISO_PIN                    GPIO_Pin_11
#define sVFD_SPI_MISO_GPIO_PORT              GPIOC
#define sVFD_SPI_MISO_GPIO_CLK               RCC_AHB1Periph_GPIOC
#define sVFD_SPI_MISO_SOURCE                 GPIO_PinSource11
#define sVFD_SPI_MISO_AF                     GPIO_AF_SPI3

#define sVFD_SPI_MOSI_PIN                    GPIO_Pin_12
#define sVFD_SPI_MOSI_GPIO_PORT              GPIOC
#define sVFD_SPI_MOSI_GPIO_CLK               RCC_AHB1Periph_GPIOC
#define sVFD_SPI_MOSI_SOURCE                 GPIO_PinSource12
#define sVFD_SPI_MOSI_AF                     GPIO_AF_SPI3

#define sVFD_SPI_NSS_PIN                     GPIO_Pin_4
#define sVFD_SPI_NSS_GPIO_PORT               GPIOA
#define sVFD_SPI_NSS_GPIO_CLK                RCC_AHB1Periph_GPIOA
#define sVFD_SPI_NSS_SOURCE                  GPIO_PinSource4
#define sVFD_SPI_NSS_AF                      GPIO_AF_SPI3

/* Exported macro ------------------------------------------------------------*/
/* Select sFLASH: Chip Select pin low */
//#define sFLASH_CS_LOW()       GPIO_ResetBits(sFLASH_CS_GPIO_PORT, sFLASH_CS_PIN)
/* Deselect sFLASH: Chip Select pin high */
//#define sFLASH_CS_HIGH()      GPIO_SetBits(sFLASH_CS_GPIO_PORT, sFLASH_CS_PIN)   

/* Exported functions ------------------------------------------------------- */

/* High layer functions  */
void sVFD_DeInit(void);
void sVFD_Init(void);

/* Low layer functions */
uint8_t sVFD_ReadByte(void);
uint8_t sVFD_SendByte(uint8_t byte);
uint16_t sVFD_SendHalfWord(uint16_t HalfWord);

#ifdef __cplusplus
}
#endif

#endif /* __SPI_FLASH_H */


/******************* (C) COPYRIGHT 2011 STMicroelectronics *****END OF FILE****/
