/**
  ******************************************************************************
  * @file    usbd_usr.c
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    22-July-2011
  * @brief   This file includes the user application layer
  ******************************************************************************
  * @attention
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2011 STMicroelectronics</center></h2>
  ******************************************************************************
  */ 

/* Includes ------------------------------------------------------------------*/
#include "usbd_usr.h"
#include "usbd_ioreq.h"
#include "ra8870.h"
//#include "display.h"

#define BIT0      1
#define BIT1      2


//uint8_t dut;	//ݴ  nNCPU  0:  1: 4030  2:MB    3:GPIB/LAN 

/** @addtogroup STM32_USB_OTG_DEVICE_LIBRARY
* @{
*/

/** @defgroup USBD_USR 
* @brief    This file includes the user application layer
* @{
*/ 

/** @defgroup USBD_USR_Private_TypesDefinitions
* @{
*/ 
/**
* @}
*/ 


/** @defgroup USBD_USR_Private_Defines
* @{
*/ 
/**
* @}
*/ 


/** @defgroup USBD_USR_Private_Macros
* @{
*/ 
/**
* @}
*/ 


/** @defgroup USBD_USR_Private_Variables
* @{
*/ 

USBD_Usr_cb_TypeDef USR_cb =
{
  USBD_USR_Init,
  USBD_USR_DeviceReset,
  USBD_USR_DeviceConfigured,
  USBD_USR_DeviceSuspended,
  USBD_USR_DeviceResumed,
};

uint8_t State = 0;
/**
* @}
*/

/** @defgroup USBD_USR_Private_Constants
* @{
*/ 

/**
* @}
*/



/** @defgroup USBD_USR_Private_FunctionPrototypes
* @{
*/ 
/**
* @}
*/ 


/** @defgroup USBD_USR_Private_Functions
* @{
*/ 

#define USER_INFORMATION1      "[Key]:Enter DFU mode after reset"
/**
* @brief  USBD_USR_Init 
*         Displays the message on LCD for host lib initialization
* @param  None
* @retval None
*/
void USBD_USR_Init(void)
{  
//    uint32_t time = 0;
    /* LCD SRAM Initial */
//	initializeFSMCSRAM();
//	InitializeRa8870();
	/* Buzzer PWM driver initial */
//	BuzzerPWMInit(2500);
//	while (time < 10000000)
//	    time++;	 
//	TIM3_CH3_PWMOUT_Init(); /* PWM for TFT LCD */
  //  drawLcdBlockBackGround(60,54 ,360,184,5); // e
//    printLcdString("BK Precision  Firmware upgrade",70,5,FONT_9X15,BK_BLUE,WHITE,NONE_TRANSPARENT);
//	printLcdString("Use numerical key to choice",70,20,FONT_9X15,BK_BLUE,WHITE,NONE_TRANSPARENT);
//    printLcdString("(1)4030  (2)MB   (3)GPIB/LAN ",70,35,FONT_9X15,BK_BLUE,WHITE,NONE_TRANSPARENT);

}

/**
* @brief  USBD_USR_DeviceReset 
*         Displays the message on LCD on device Reset Event
* @param  speed : device speed
* @retval None
*/
void USBD_USR_DeviceReset(uint8_t speed )
{
 switch (speed)
 {
   case USB_OTG_SPEED_HIGH: 
//     LCD_LOG_SetFooter ("     USB Device Library v1.0.0 [HS]" );
     break;

  case USB_OTG_SPEED_FULL: 
//     LCD_LOG_SetFooter ("     USB Device Library v1.0.0 [FS]" );
//	 printLcdString("USB Device Library v1.0.0 [FS]",70,250,FONT_9X15,GRAY2,WHITE,NONE_TRANSPARENT);
     break;
 default:
//     LCD_LOG_SetFooter ("     USB Device Library v1.0.0 [??]" );
     break;
     
 }
}


/**
* @brief  USBD_USR_DeviceConfigured
*         Displays the message on LCD on device configuration Event
* @param  None
* @retval Staus
*/
void USBD_USR_DeviceConfigured (void)
{
  if (State == 0)
  {
//    LCD_UsrLog("> DFU Interface Started.\n");
        printText(70,65,"> DFU   Interface Started.      ");
		SET_USB_CONNECTBEEP;
  }
  else if (State >= 1)
  {
//    LCD_UsrLog("> DFU Interface Configured.\n");
        printText(70,65,"> DFU   Interface Configured.   ");
 
  }
  
  State++;
//  if (State == 2)
//  	State = 1;
}
/**
* @brief  USBD_USR_DeviceSuspended 
*         Displays the message on LCD on device suspend Event
* @param  None
* @retval None
*/
void USBD_USR_DeviceSuspended(void)
{
//  LCD_UsrLog("> USB Device in Suspend Mode.\n");
        printText(70,65,"> USB   Device in Suspend Mode. ");
		SET_USB_DISCONNECTBEEP;
		State = 0;
  /* Users can do their application actions here for the USB-Reset */
}


/**
* @brief  USBD_USR_DeviceResumed 
*         Displays the message on LCD on device resume Event
* @param  None
* @retval None
*/
void USBD_USR_DeviceResumed(void)
{
  //  LCD_UsrLog("> USB Device in Idle Mode.\n");
        printText(70,65,"> USB   Device in Idle Mode.    ");
  /* Users can do their application actions here for the USB-Reset */
}
/**
* @}
*/ 

/**
* @}
*/ 

/******************* (C) COPYRIGHT 2011 STMicroelectronics *****END OF FILE****/






























