/**
  ******************************************************************************
  * @file    USART/USART_Printf/stm32f2xx_it.c 
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    18-April-2011
  * @brief   Main Interrupt Service Routines.
  *          This file provides template for all exceptions handler and 
  *          peripherals interrupt service routine.
  ******************************************************************************
  * @attention
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2011 STMicroelectronics</center></h2>
  ******************************************************************************
  */ 

/* Includes ------------------------------------------------------------------*/
#include "includes.h"
#include "usb_dcd_int.h"
#include "scpi.h"
void  EVAL_COM_IRQHandler(void);
void channel(COM_TypeDef COM); //measureMB(void)

uint8_t faultflag;

#ifdef I_WATCH_DOG
extern __IO uint32_t TimingDelay;
extern __IO uint32_t PeriodValue;
extern __IO uint32_t CaptureNumber;
uint16_t tmpCC4[2] = {0, 0};
#endif

/** @addtogroup STM32F2xx_StdPeriph_Examples
  * @{
  */

/** @addtogroup USART_Printf
  * @{
  */ 

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/

/* Private functions ---------------------------------------------------------*/

/******************************************************************************/
/*            Cortex-M3 Processor Exceptions Handlers                         */
/******************************************************************************/

/**
  * @brief   This function handles NMI exception.
  * @param  None
  * @retval None
  */
void NMI_Handler(void)
{
}

/**
  * @brief  This function handles Hard Fault exception.
  * @param  None
  * @retval None
  */
void HardFault_Handler(void)
{
  faultflag = 1;
  HARDFAULT_TEST_HIGH;
  /* Go to infinite loop when Hard Fault exception occurs */
  while (faultflag != 0)
  {
  }
}

/**
  * @brief  This function handles Memory Manage exception.
  * @param  None
  * @retval None
  */
void MemManage_Handler(void)
{
faultflag = 2;
  /* Go to infinite loop when Memory Manage exception occurs */
  while (faultflag != 0)
  {
  }
}

/**
  * @brief  This function handles Bus Fault exception.
  * @param  None
  * @retval None
  */
void BusFault_Handler(void)
{
faultflag = 3;
  /* Go to infinite loop when Bus Fault exception occurs */
  while (faultflag  != 0)
  {
  }
}

/**
  * @brief  This function handles Usage Fault exception.
  * @param  None
  * @retval None
  */
void UsageFault_Handler(void)
{
faultflag = 4;
  /* Go to infinite loop when Usage Fault exception occurs */
  while (faultflag !=0)
  {
  }
}

/**
  * @brief  This function handles SVCall exception.
  * @param  None
  * @retval None
  */
void SVC_Handler(void)
{
}

/**
  * @brief  This function handles Debug Monitor exception.
  * @param  None
  * @retval None
  */
void DebugMon_Handler(void)
{
}

/**
  * @brief  This function handles PendSVC exception.
  * @param  None
  * @retval None
  */
void PendSV_Handler(void)
{
}

/**
  * @brief  This function handles SysTick Handler.
  * @param  None
  * @retval None
  */
extern void systemTickIsr(void);
void SysTick_Handler(void)
{
   systemTickIsr();
}

/******************************************************************************/
/*                 STM32F2xx Peripherals Interrupt Handlers                   */
/*  Add here the Interrupt Handler for the used peripheral(s) (PPP), for the  */
/*  available peripheral interrupt handler's name please refer to the startup */
/*  file (startup_stm32f2xx.s).                                               */
/******************************************************************************/

/**
  * @brief  This function handles PPP interrupt request.
  * @param  None
  * @retval None
  */
/*void PPP_IRQHandler(void)
{
}*/
uint8_t syncStatus = LOW;

extern void runningTimerISR(void);
extern void displayTmerISR(void);
extern void timeTickIsr(void);
extern uint8_t endProgramming[5];
extern uint8_t endPattern[5];
extern void uartxIsr(COM_TypeDef COM);


void WWDG_IRQHandler(void)		// Window WatchDog 
{
}
/**
  * @brief  This function handles the PVD Output interrupt request.
  * @param  None
  * @retval None
  */
void PVD_IRQHandler(void)
{
  if(EXTI_GetITStatus(EXTI_Line16) != RESET)
  {
	if (PVDState == 0 )						   // VDD 3.3V UӧC2.0V
		PVDState = 1;
	else if(PVDState == 1)					  // VDD A 2.0V
	{
		PVDState = 0;
		NVIC_SystemReset(); // software reset
	}
    /* Clear the Key Button EXTI line pending bit */
    EXTI_ClearITPendingBit(EXTI_Line16);
  }
}
void TAMP_STAMP_IRQHandler(void)// Tamper and TimeStamps through the EXTI line            
{
}                
			
void RTC_WKUP_IRQHandler(void)// RTC Wakeup through the EXTI line                       
{
}          
void FLASH_IRQHandler(void)// FLASH                                           
{
}                
void RCC_IRQHandler(void)// RCC
{
}                                             
void EXTI0_IRQHandler(void)// EXTI Line0
{
}                                             
void EXTI1_IRQHandler(void)// EXTI Line1 
{
}                                             
/**
  * @brief  This function handles the rs485 slave SYNC input interrupt request.
  * @param  None
  * @retval None
  */


void EXTI2_IRQHandler(void)
{

  if(EXTI_GetITStatus(EXTI_Line2) != RESET)
  {
    /* SYNC PIN */
    if (parallelMode == ON && parallelRole != MASTER)	// parallel Mode slave
	{
		sendMBStateSetting(MEASURE_CHANNEL,OUTPUT_CMD, (uint8_t)onoffStatus);
		sendMBStateSetting(MEASURE_CHANNEL,OUTPUT_CMD, (uint8_t)onoffStatus);
	}
    /* Clear the EXTI line 2 pending bit */
    EXTI_ClearITPendingBit(EXTI_Line2);
  }

}
   

                                        
void EXTI3_IRQHandler(void)// EXTI Line3
{
}                                             
void EXTI4_IRQHandler(void)// EXTI Line4
{
}                                             
//void DMA1_Stream0_IRQHandler(void)// DMA1 Stream 0
//{
//}                                             
void DMA1_Stream1_IRQHandler(void)// DMA1 Stream 1
{
}                                             
void DMA1_Stream2_IRQHandler(void)// DMA1 Stream 2
{
}                                             
void DMA1_Stream3_IRQHandler(void)// DMA1 Stream 3
{
}            
void DMA1_Stream4_IRQHandler(void)// DMA1 Stream 4
{
}                                             
void DMA1_Stream5_IRQHandler(void)// DMA1 Stream 5
{
}                                             
//void DMA1_Stream6_IRQHandler(void)// DMA1 Stream 6
//{
//}                                             
void ADC_IRQHandler(void)// ADC1, ADC2 and ADC3s
{
}                                             
void CAN1_TX_IRQHandler(void)// CAN1 TX
{
}            
void CAN1_RX0_IRQHandler(void)// CAN1 RX0
{
}                                             
void CAN1_RX1_IRQHandler(void)// CAN1 RX1
{
}                                             
void CAN1_SCE_IRQHandler(void)// CAN1 SCE 
{
}                                             
/**
  * @brief  This function handles External lines 9 to 5 interrupt request.
  * @param  None
  * @retval None
  */
void EXTI9_5_IRQHandler(void)	   //EXTILine9_Config

{
  if(EXTI_GetITStatus(EXTI_Line8) != RESET)
  {
    /* ENABLE_CPU ON/OFF control */
    
    /* Clear the EXTI line 8 pending bit */
    EXTI_ClearITPendingBit(EXTI_Line8);
  }
  if(EXTI_GetITStatus(EXTI_Line9) != RESET)
  {
    /* SHUTOFF_CPU  */
    
//    if (chainMode == ON && onoffStatus == ON)	// when chainMode ON this is emerengcy switch
	{
		if (extShutOffLogic == FALLING_EDGE)// off/Low Logic
		{
			if (SHUTOFF_CPU_PIN == SET) 
			{
				if(onoffStatus == ON)
				{
					onoffStatus = OFF;
					sendMBStateSetting(MEASURE_CHANNEL,OUTPUT_CMD, (uint8_t)onoffStatus);
					sendMBStateSetting(MEASURE_CHANNEL,OUTPUT_CMD, (uint8_t)onoffStatus);
					if (chainMode == ON || parallelMode == ON)
						beep(4); // beep 3 
				}
			}
		}
		else  // high Logic
		{
			if (SHUTOFF_CPU_PIN != SET)  // SHUTOFF_CPU
			{
				if (onoffStatus == ON)
				{
					onoffStatus = OFF;
					sendMBStateSetting(MEASURE_CHANNEL,OUTPUT_CMD, (uint8_t)onoffStatus);
					sendMBStateSetting(MEASURE_CHANNEL,OUTPUT_CMD, (uint8_t)onoffStatus);
					if (chainMode == ON || parallelMode == ON)
						beep(4);  // beep 3s 
				}
			}
		}
	}    
    /* Clear the EXTI line 9 pending bit */
    EXTI_ClearITPendingBit(EXTI_Line9);
  }
}

                                  
void TIM1_BRK_TIM9_IRQHandler(void)// TIM1 Break and TIM9
{
}   
  
void TIM1_UP_TIM10_IRQHandler(void)          // TIM1 Update and TIM10
{
}                                             
void TIM1_TRG_COM_TIM11_IRQHandler(void)     // TIM1 Trigger and Commutation and TIM11
{
}                                             
void TIM1_CC_IRQHandler(void)                // TIM1 Capture Compare
{
}                                             
void TIM2_IRQHandler(void)
{
	runningTimerISR();
}
void TIM3_IRQHandler(void)                //TIM3
{
}                                             
/**
  * @brief  TIM4_IRQHandler.(keyboard scan and debounce) 1ms
  * @param  None
  * @retval None
  */
void TIM4_IRQHandler(void)
{
	 timeTickIsr();
}
void I2C1_EV_IRQHandler(void)                // I2C1 Event
{
}                                             
void I2C1_ER_IRQHandler(void)                // I2C1 Error
{
}                                             
void I2C2_EV_IRQHandler(void)                // I2C2 Event
{
}                                             
void I2C2_ER_IRQHandler(void)                // I2C2 Error
{
}                                             

void SPI1_IRQHandler(void)                // SPI1
{
}                                             
void SPI2_IRQHandler(void)                // SPI2 
{
}                                             
void  USART1_IRQHandler(void)
{
    uartxIsr(COM1);
}
//void USART2_IRQHandler(void)                // USART2 
//{
//}                                             
//void USART3_IRQHandler(void)                // USART3
//{
//}  

/**
  * @brief  This function handles External lines 15 to 10 interrupt request.
  * @param  None
  * @retval None
  */
void EXTI15_10_IRQHandler(void)
{
  if(EXTI_GetITStatus(EXTI_Line10) != RESET)
  {
    /* LOC/ANA_CPU  */
    
    /* Clear the EXTI line 10 pending bit */
    EXTI_ClearITPendingBit(EXTI_Line10);
  }
}                                           
void RTC_Alarm_IRQHandler(void)                // RTC Alarm (A and B) through EXTI Line 
{
}                                             
 void OTG_FS_WKUP_IRQHandler(void)                // USB OTG FS Wakeup through EXTI line
{
}                                             
void TIM8_BRK_TIM12_IRQHandler(void)                // TIM8 Break and TIM12 
{
}                                             
void TIM8_UP_TIM13_IRQHandler(void)                // TIM8 Update and TIM13
{
}  


void TIM8_TRG_COM_TIM14_IRQHandler(void)                //TIM8 Trigger and Commutation and TIM14
{
}                                             
void TIM8_CC_IRQHandler(void)                // TIM8 Capture Compare 
{
}                                             
 void DMA1_Stream7_IRQHandler(void)                //DMA1 Stream7
{
}                                             
void FSMC_IRQHandler(void)                // FSMC 
{
}                                             
void SDIO_IRQHandler(void)                //SDIO
{
}  
/**
  * @brief  This function handles TIM5 global interrupt request.
  * @param  None
  * @retval None
  */
void TIM5_IRQHandler(void)
{
#ifdef I_WATCH_DOG

  if (TIM_GetITStatus(TIM5, TIM_IT_CC4) != RESET)
  {    
    /* Get the Input Capture value */
    tmpCC4[CaptureNumber++] = TIM_GetCapture4(TIM5);
   
    /* Clear CC4 Interrupt pending bit */
    TIM_ClearITPendingBit(TIM5, TIM_IT_CC4);

    if (CaptureNumber >= 2)
    {
      /* Compute the period length */
      PeriodValue = (uint16_t)(0xFFFF - tmpCC4[0] + tmpCC4[1] + 1);
    }
  }
#endif
}

                                            
void SPI3_IRQHandler(void)                // SPI3 
{
}                                             
//void UART4_IRQHandler(void)                // UART4
//{
//}                                             
void UART5_IRQHandler(void)                // UART5 
{
}                                             
void TIM6_DAC_IRQHandler(void)                // TIM6 and DAC1&2 underrun errors
{
}  


void TIM7_IRQHandler(void)                // TIM7
{
}                                             
void DMA2_Stream0_IRQHandler(void)                // DMA2 Stream 0 
{
}                                             
 void DMA2_Stream1_IRQHandler(void)                // DMA2 Stream 1
{
}                                             
void DMA2_Stream2_IRQHandler(void)                // DMA2 Stream 2  
{
}                                             
void DMA2_Stream3_IRQHandler(void)                // DMA2 Stream 3
{
}  


void DMA2_Stream4_IRQHandle(void)                // DMA2 Stream 4
{
}                                             
void ETH_IRQHandler(void)                // Ethernet
{
}                                             
 void ETH_WKUP_IRQHandler(void)                // Ethernet Wakeup through EXTI line 
{
}                                             
void CAN2_TX_IRQHandler(void)                //CAN2 TX 
{
}                                             
void TCAN2_RX0_IRQHandler(void)                // CAN2 RX0
{
}  

                                           
void CAN2_RX1_IRQHandler(void)                // CAN2 RX1
{
}                                             
void CAN2_SCE_IRQHandler(void)                // CAN2 SCE
{
}                                             
/**
  * @brief  OTG_FS_IRQHandler
  *          This function handles USB-On-The-Go FS global interrupt request.
  *          requests.USB CDC
  * @param  None
  * @retval None
  */
void OTG_FS_IRQHandler(void)
{
    USBD_OTG_ISR_Handler (&USB_OTG_dev);
}
void DMA2_Stream5_IRQHandler(void)                // DMA2 Stream 5 
{
}                                             
void DMA2_Stream6_IRQHandler(void)                // DMA2 Stream 6
{
}  

void DMA2_Stream7_IRQHandler(void)                //DMA2 Stream 7
{
}                                             
void  USART6_IRQHandler(void)                //USART6 
{
}                                             
 void I2C3_EV_IRQHandler(void)                // I2C3 event 
{
}                                             
void I2C3_ER_IRQHandler(void)                // I2C3 error 
{
}                                             
void OTG_HS_EP1_OUT_IRQHandler(void)                //USB OTG HS End Point 1 Out
{
}



void OTG_HS_EP1_IN_IRQHandler(void)                // USB OTG HS End Point 1 In
{
}                                             
void OTG_HS_WKUP_IRQHandler(void)                // USB OTG HS Wakeup through EXTI
{
}                                             
 void  OTG_HS_IRQHandler(void)                // USB OTG HS 
{
}                                             
voidDCMI_IRQHandler(void)                // DCMI 
{
}                                             
void  CRYP_IRQHandler(void)                //CRYP crypto
{
}

 void HASH_RNG_IRQHandler(void)                //Hash and Rng
{
}






#if (HARDWARE_VERSION >= VERSIPN_C)
void  USART3_IRQHandler(void)
{
	if (transparentHOST == NOT_PROGRAMMING)
		uartxIsr(COM3);
	else   	
		EVAL_COM_IRQHandler();
}
#else
void  USART2_IRQHandler(void)
{
	if (transparentHOST == NOT_PROGRAMMING)
		uartxIsr(COM2);
	else   	
		EVAL_COM_IRQHandler();
}
#endif

#if (HARDWARE_VERSION >= VERSIPN_C)
void  UART4_IRQHandler(void)
{
	//#ifdef VCP_TO_COM	 // ]wizLVCPgUSART UO N{,UOݥNUSART IAP bootloader
	if (transparentHOST == NOT_PROGRAMMING)
		uartxIsr(COM4);
	else   	
		EVAL_COM_IRQHandler();

}
#else
void  USART3_IRQHandler(void)
{
	//#ifdef VCP_TO_COM	 // ]wizLVCPgUSART UO N{,UOݥNUSART IAP bootloader
	if (transparentHOST == NOT_PROGRAMMING)
		uartxIsr(COM3);
	else   	
		EVAL_COM_IRQHandler();
}


#endif

#if (HARDWARE_VERSION >= VERSIPN_C)
void  USART2_IRQHandler(void)
{
	if (transparentHOST == NOT_PROGRAMMING)
		uartxIsr(COM2);
	else   	
		EVAL_COM_IRQHandler();
}

#else
void  UART4_IRQHandler(void)
{
	if (transparentHOST == NOT_PROGRAMMING)
		uartxIsr(COM4);
	else   	
		EVAL_COM_IRQHandler();
}

#endif



















/**
  * @}
  */ 

/**
  * @}
  */ 

/******************* (C) COPYRIGHT 2011 STMicroelectronics *****END OF FILE****/
