/**
  ******************************************************************************
  * @file    usbd_cdc_vcp.c
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    22-July-2011
  * @brief   Generic media access Layer.
  ******************************************************************************
  * @attention
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2011 STMicroelectronics</center></h2>
  ******************************************************************************
  */ 

#ifdef USB_OTG_HS_INTERNAL_DMA_ENABLED 
#pragma     data_alignment = 4 
#endif /* USB_OTG_HS_INTERNAL_DMA_ENABLED */

/* Includes ------------------------------------------------------------------*/
#include "includes.h"
#include "usbd_cdc_vcp.h"
#include "usbd_req.h"
//#include "hardware.h"
//#include "uart.h"

uint16_t controlLineState;

extern  uint32_t APP_Rx_ptr_in;
extern  uint32_t APP_Rx_ptr_out;


#define  BIT2				4

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/

#ifdef   VCP_TO_COM
LINE_CODING linecoding =
  {
    9600, /* baud rate*/
    0x00,   /* stop bits-1*/
    0x00,   /* parity - none*/
    0x08    /* nb. of bits 8*/
  };

#else
LINE_CODING linecoding =
  {
    115200, /* baud rate*/
    0x00,   /* stop bits-1*/
    0x00,   /* parity - none*/
    0x08    /* nb. of bits 8*/
  };
#endif

#define NETWORK_CONNECTION 		0x00
#define RESPONSE_AVAILABLE		0x01
#define SERIAL_STATE 			0x20
#define LINE_STATE_CHANGE 		0x29
#define CONNECTION_SPEED_CHANGE 0x2A



//USART_InitTypeDef USART_InitStructure;

/* These are external variables imported from CDC core to be used for IN 
   transfer management. */
extern uint8_t  APP_Rx_Buffer []; /* Write CDC received data in this buffer.
                                     These data will be sent over USB IN endpoint
                                     in the CDC core functions. */
extern uint32_t APP_Rx_ptr_in;    /* Increment this pointer or roll it back to
                                     start address when writing received data
                                     in the buffer APP_Rx_Buffer. */



uint8_t usbCdcRxbuffer[256];  /* USB CDC ư */
uint8_t usbCdcRxLength = 0;

/* Private function prototypes -----------------------------------------------*/
static uint16_t VCP_Init     (void);
static uint16_t VCP_DeInit   (void);
static uint16_t VCP_Ctrl     (uint32_t Cmd, uint8_t* Buf, uint32_t Len);
static uint16_t VCP_DataTx   (uint8_t* Buf, uint32_t Len);
static uint16_t VCP_DataRx   (uint8_t* Buf, uint32_t Len);

static uint16_t VCP_COMConfig(uint8_t Conf);

CDC_IF_Prop_TypeDef VCP_fops = 
{
  VCP_Init,
  VCP_DeInit,
  VCP_Ctrl,
  VCP_DataTx,
  VCP_DataRx
};

/* Private functions ---------------------------------------------------------*/
/**
  * @brief  VCP_Init
  *         Initializes the Media on the STM32
  * @param  None
  * @retval Result of the opeartion (USBD_OK in all cases)
  */
static uint16_t VCP_Init(void)
{
  USART_InitTypeDef USART_InitStructure;
  /* EVAL_COM1 default configuration */
  /* EVAL_COM1 configured as follow:
        - BaudRate = 115200 baud  
        - Word Length = 8 Bits
        - One Stop Bit
        - Parity Odd
        - Hardware flow control disabled
        - Receive and transmit enabled
  */
  USART_InitStructure.USART_BaudRate = 9600; //115200
  USART_InitStructure.USART_WordLength = USART_WordLength_8b;
  USART_InitStructure.USART_StopBits = USART_StopBits_1;
  USART_InitStructure.USART_Parity = USART_Parity_No;//USART_Parity_Odd;
  USART_InitStructure.USART_HardwareFlowControl = USART_HardwareFlowControl_None;
  USART_InitStructure.USART_Mode = USART_Mode_Rx | USART_Mode_Tx;
  USARTx_Configuration(USB_VCP_CHANNEL,&USART_InitStructure); 
  return USBD_OK;
}

/**
  * @brief  VCP_DeInit
  *         DeInitializes the Media on the STM32
  * @param  None
  * @retval Result of the opeartion (USBD_OK in all cases)
  */
static uint16_t VCP_DeInit(void)
{

  return USBD_OK;
}


/**
  * @brief  VCP_Ctrl
  *         Manage the CDC class requests
  * @param  Cmd: Command code            
  * @param  Buf: Buffer containing command data (request parameters)
  * @param  Len: Number of data to be sent (in bytes)
  * @retval Result of the opeartion (USBD_OK in all cases)
  */
static uint16_t VCP_Ctrl (uint32_t Cmd, uint8_t* Buf, uint32_t Len)
{ 
  USB_SETUP_REQ req;
  USBD_ParseSetupRequest(&USB_OTG_dev , &req);
  switch (Cmd)
  {
  case SEND_ENCAPSULATED_COMMAND:
    /* Not  needed for this driver */
    break;

  case GET_ENCAPSULATED_RESPONSE:
    /* Not  needed for this driver */
    break;

  case SET_COMM_FEATURE:
    /* Not  needed for this driver */
    break;

  case GET_COMM_FEATURE:
    /* Not  needed for this driver */
    break;

  case CLEAR_COMM_FEATURE:
    /* Not  needed for this driver */
    break;

  case SET_LINE_CODING:	   /* 0x20 */
    linecoding.bitrate = (uint32_t)(Buf[0] | (Buf[1] << 8) | (Buf[2] << 16) | (Buf[3] << 24));
    linecoding.format = Buf[4];
    linecoding.paritytype = Buf[5];
    linecoding.datatype = Buf[6];
    /* Set the new configuration */
    VCP_COMConfig(OTHER_CONFIG);
	SET_VCP_CONNECT;	  // nsW M buffer
	 memset((void *)&uartBuffer[USB_VCP_CHANNEL], 0 , sizeof(UARTx_BUFFER));
	 APP_Rx_ptr_in = APP_Rx_ptr_out = usb_channel_count = 0;

    break;

  case GET_LINE_CODING:	   /* 0x21 */
    Buf[0] = (uint8_t)(linecoding.bitrate);
    Buf[1] = (uint8_t)(linecoding.bitrate >> 8);
    Buf[2] = (uint8_t)(linecoding.bitrate >> 16);
    Buf[3] = (uint8_t)(linecoding.bitrate >> 24);
    Buf[4] = linecoding.format;
    Buf[5] = linecoding.paritytype;
    Buf[6] = linecoding.datatype; 

    break;

  case SET_CONTROL_LINE_STATE:	/* 0x22 */
    /* Not  needed for this driver */
	CLR_VCP_CONNECT;		 // n			 
//	 memset((void *)&uartBuffer[USB_VCP_CHANNEL], 0 , sizeof(UARTx_BUFFER));   M bufferʧ@   pc nӧ ɭP UI command |Bz  ,M buffer ʰ ȦbsWɰ
//	 usb_channel_count = 0;
//	 APP_Rx_ptr_in = APP_Rx_ptr_out = usb_channel_count = 0;

//	memset((void *)Buf,0,10);
//	controlLineState  = ((controlLineState&0xFFF0) | req.wValue);
//	Buf[10] = 0xA1;
//	Buf[0] = 0xA1;
//	Buf[1] = SERIAL_STATE;
//	Buf[6] = 2;/* length=2 */
//	Buf[8] = 3;/* dcd and dsr high */
	/* Send the data to the host */
  //  USBD_CtlSendData (&USB_OTG_dev, 
  //                    Buf,
  //                    10); */
    break;

  case SEND_BREAK:
    /* Not  needed for this driver */
    break;    
    
  default:
    break;
  }

  return USBD_OK;
}

/**
  * @brief  VCP_DataTx
  *         CDC received data to be send over USB IN endpoint are managed in 
  *         this function.
  * @param  Buf: Buffer of data to be sent
  * @param  Len: Number of data to be sent (in bytes)
  * @retval Result of the opeartion: USBD_OK if all operations are OK else VCP_FAIL
  */

uint8_t endProgramming[8];
uint8_t endPattern[] = "ENDDL\r\n";//{0xE7,0x02,0x0A,0xB0,0x00};

void usbDelayMs(uint32_t time)
{
	uint32_t time1;
	time *= 30000;
	for (time1 = 0;time1 < time;time1++)
	{
		__nop();
		__nop();
		__nop();
		__nop();
	}
}


void checkIfRestart(void)
{
	if (strcmp((void *)endProgramming,(void *)endPattern) == 0)
		SET_USB_RESTART;
}



static uint16_t VCP_DataTx (uint8_t* Buf, uint32_t Len)
{
  if (linecoding.datatype == 7)
  {
  	if (transparentHOST == VCP_TO_COMport)
    	APP_Rx_Buffer[APP_Rx_ptr_in] = USART_ReceiveData(COM_USART[transparentDEVICE]) & 0x7F;
	else
      	APP_Rx_Buffer[APP_Rx_ptr_in] = *(Buf);
  }
  else if (linecoding.datatype == 8)
  {
   	if (transparentHOST == VCP_TO_COMport)
    	APP_Rx_Buffer[APP_Rx_ptr_in] = USART_ReceiveData(COM_USART[transparentDEVICE]); //qUART i i USB transmit buffer 
	else	
	  	APP_Rx_Buffer[APP_Rx_ptr_in] = *(Buf);
  }
  endProgramming[0] = endProgramming[1];
  endProgramming[1] = endProgramming[2];
  endProgramming[2] = endProgramming[3];
  endProgramming[3] = endProgramming[4];
  endProgramming[4] = endProgramming[5];
  endProgramming[5] = endProgramming[6];
  endProgramming[6] = APP_Rx_Buffer[APP_Rx_ptr_in];
  endProgramming[7] = 0;
  checkIfRestart();	// software reset  UN񧹦 }
  APP_Rx_ptr_in++;
  // To avoid buffer overflow 
  if(APP_Rx_ptr_in == APP_RX_DATA_SIZE)
  {						   
    APP_Rx_ptr_in = 0;
  }  
  return USBD_OK;
}

/**
  * @brief  VCP_DataRx
  *         Data received over USB OUT endpoint are sent over CDC interface 
  *         through this function.
  *           
  *         @note
  *         This function will block any OUT packet reception on USB endpoint 
  *         untill exiting this function. If you exit this function before transfer
  *         is complete on CDC interface (ie. using DMA controller) it will result 
  *         in receiving more data while previous ones are still not sent.
  *                 
  * @param  Buf: Buffer of data to be received
  * @param  Len: Number of data received (in bytes)
  * @retval Result of the opeartion: USBD_OK if all operations are OK else VCP_FAIL
  */
static uint16_t VCP_DataRx (uint8_t* Buf, uint32_t Len)
{
	uint32_t i;
	uint8_t uartData;
  	for (i = 0; i < Len; i++)
  	{
		if (transparentHOST == VCP_TO_COMport)
		{
 			endProgramming[i] = *(Buf + i);	  //ʱ "ENDDL\r\n" 
			endProgramming[7] = 0;
 			checkIfRestart();	// software reset  UN񧹦 }
			USART_SendData(COM_USART[transparentDEVICE], *(Buf + i) );	   // o̬ONCDCǵ USART3
	      	while(USART_GetFlagStatus(COM_USART[transparentDEVICE], USART_FLAG_TXE) == RESET); 
	    }
		else
		{
			uartData = 	*(Buf + i);
			switch(uartData)
			{
				case '\r':
				case '\n':
					if (uartBuffer[USB_VCP_CHANNEL].prev == 0)	// if not EOL
					{
					 	uartBuffer[USB_VCP_CHANNEL].rxBuffer[uartBuffer[USB_VCP_CHANNEL].rxHead++] = '\r'; // make 0x0d
						//uartBuffer[USB_VCP_CHANNEL].packetCount++;	// increase packet count to info foreground
						usb_channel_count++;
						uartBuffer[USB_VCP_CHANNEL].prev = 1; // EOL
					}
					break;
				default:
					uartBuffer[USB_VCP_CHANNEL].rxBuffer[uartBuffer[USB_VCP_CHANNEL].rxHead++] = uartData;
					uartBuffer[USB_VCP_CHANNEL].prev = 0;	// clear EOL
					break;
			}
//			CLR_485_CHANNEL;
		}
  	} 
  	return USBD_OK;
}

/**															er
  * @brief  VCP_COMConfig
  *         Configure the COM Port with default values or values received from host.
  * @param  Conf: can be DEFAULT_CONFIG to set the default configuration or OTHER_CONFIG
  *         to set a configuration received from the host.		  a
  * @retval None.
  */
static uint16_t VCP_COMConfig(uint8_t Conf)
{
  USART_InitTypeDef USART_InitStructure;
  if (Conf == DEFAULT_CONFIG)  
  {
    /* EVAL_COM1 default configuration */
    /* EVAL_COM1 configured as follow:
    - BaudRate = 115200 baud  
    - Word Length = 8 Bits
    - One Stop Bit
    - Parity Odd
    - Hardware flow control disabled
    - Receive and transmit enabled
    */
    USART_InitStructure.USART_BaudRate = 9600;//115200;
    USART_InitStructure.USART_WordLength = USART_WordLength_8b;
    USART_InitStructure.USART_StopBits = USART_StopBits_1;
    USART_InitStructure.USART_Parity = USART_Parity_No;//USART_Parity_Odd;
    USART_InitStructure.USART_HardwareFlowControl = USART_HardwareFlowControl_None;
    USART_InitStructure.USART_Mode = USART_Mode_Rx | USART_Mode_Tx;
    /* Configure and enable the USART */
    STM_EVAL_COMInit(USB_VCP_CHANNEL, &USART_InitStructure);
    /* Enable the USART Receive interrupt */
    USART_ITConfig(COM_USART[USB_VCP_CHANNEL], USART_IT_RXNE, ENABLE);
  }
  else
  {
    /* set the Stop bit*/
    switch (linecoding.format)
    {
    case 0:
      USART_InitStructure.USART_StopBits = USART_StopBits_1;
      break;
    case 1:
      USART_InitStructure.USART_StopBits = USART_StopBits_1_5;
      break;
    case 2:
      USART_InitStructure.USART_StopBits = USART_StopBits_2;
      break;
    default :
      VCP_COMConfig(DEFAULT_CONFIG);
      return (USBD_FAIL);
    }
    
    /* set the parity bit*/
    switch (linecoding.paritytype)
    {
    case 0:
      USART_InitStructure.USART_Parity = USART_Parity_No;
      break;
    case 1:
      USART_InitStructure.USART_Parity = USART_Parity_Even;
      break;
    case 2:
      USART_InitStructure.USART_Parity = USART_Parity_Odd;
      break;
    default :
      VCP_COMConfig(DEFAULT_CONFIG);
      return (USBD_FAIL);
    }
    
    /*set the data type : only 8bits and 9bits is supported */
    switch (linecoding.datatype)
    {
    case 0x07:
      /* With this configuration a parity (Even or Odd) should be set */
      USART_InitStructure.USART_WordLength = USART_WordLength_8b;
      break;
    case 0x08:
      if (USART_InitStructure.USART_Parity == USART_Parity_No)
      {
        USART_InitStructure.USART_WordLength = USART_WordLength_8b;
      }
      else 
      {
        USART_InitStructure.USART_WordLength = USART_WordLength_9b;
      }
      
      break;
    default :
      VCP_COMConfig(DEFAULT_CONFIG);
      return (USBD_FAIL);
    }
    
    USART_InitStructure.USART_BaudRate = linecoding.bitrate;
    USART_InitStructure.USART_HardwareFlowControl = USART_HardwareFlowControl_None;
    USART_InitStructure.USART_Mode = USART_Mode_Rx | USART_Mode_Tx;
    /* Configure and enable the USART */
    STM_EVAL_COMInit(USB_VCP_CHANNEL, &USART_InitStructure);
  }
  return USBD_OK;
}

/**
  * @brief  EVAL_COM_IRQHandler
  *         
  * @param  None.
  * @retval None.
  */
//#define EVAL_COM_IRQHandler            USART3_IRQHandler
extern void uartxIsr(COM_TypeDef COM);

void EVAL_COM_IRQHandler(void)
{
  		if (USART_GetITStatus(COM_USART[transparentDEVICE], USART_IT_RXNE) != RESET)
  		{
    		/* Send the received data to the PC Host*/
			if (transparentHOST == VCP_TO_COMport)
    			VCP_DataTx (0,0);
			else if(transparentHOST == RS232_TO_COMport)
			{
				uint16_t Data,i;
				Data = USART_ReceiveData(COM_USART[transparentDEVICE]);
				USART_SendData(COM_USART[transparentHOST],Data);
 				for(i = 0;i < 7 ;i++)
					endProgramming[i] = endProgramming[i + 1];
				endProgramming[6] = Data;endProgramming[7] = 0;
				checkIfRestart();	// software reset  UN񧹦 }
			}
  		}
  		if (USART_GetITStatus(COM_USART[transparentHOST], USART_IT_RXNE) != RESET)
  		{
			uint16_t Data,i;
    		/* Send the received data to the Device*/
			Data = USART_ReceiveData(COM_USART[transparentHOST]);
			USART_SendData(COM_USART[transparentDEVICE],Data);
 			for(i = 0;i < 7 ;i++)
				endProgramming[i] = endProgramming[i + 1];
			endProgramming[6] = Data;endProgramming[7] = 0;
			checkIfRestart();	// software reset  UN񧹦 }
  		}
  /* If overrun condition occurs, clear the ORE flag and recover communication */
  		if (USART_GetFlagStatus(COM_USART[transparentDEVICE], USART_FLAG_ORE) != RESET)
  		{
    		(void)USART_ReceiveData(COM_USART[transparentDEVICE]);
  		}
  		if (USART_GetFlagStatus(COM_USART[transparentHOST], USART_FLAG_ORE) != RESET)
  		{
    		(void)USART_ReceiveData(COM_USART[transparentHOST]);
  		}
		checkIfRestart();	// software reset  UN񧹦 }		
}

void usbCdcTx(uint8_t *buf,uint8_t len)
{
    uint8_t i;
//	if (IS_VCP_CONNECT)
	{
		for (i = 0; i < len;i++)
		{
	    	VCP_DataTx (buf++,0);
		}
	}
}


/******************* (C) COPYRIGHT 2011 STMicroelectronics *****END OF FILE****/
