/**
  ******************************************************************************
  * @file    usbh_usr.c
  * @author  MCD Application Team
  * @version V2.0.0
  * @date    22-July-2011
  * @brief   This file includes the usb host library user callbacks
  ******************************************************************************
  * @attention
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2011 STMicroelectronics</center></h2>
  ******************************************************************************
  */

/* Includes ------------------------------------------------------------------*/
#include <string.h>
#include "usbh_usr.h"
#include "ff.h"       /* FATFS */
#include "usbh_msc_core.h"
#include "usbh_msc_scsi.h"
#include "usbh_msc_bot.h"
#include "includes.h"
/** @addtogroup USBH_USER
* @{
*/

/** @addtogroup USBH_MSC_DEMO_USER_CALLBACKS
* @{
*/

/** @defgroup USBH_USR 
* @brief    This file includes the usb host stack user callbacks
* @{
*/ 

/** @defgroup USBH_USR_Private_TypesDefinitions
* @{
*/ 
/**
* @}
*/ 
extern USB_OTG_CORE_HANDLE          USB_OTG_Core;
extern USBH_HOST                    USB_Host;


/** @defgroup USBH_USR_Private_Defines
* @{
*/ 
#define IMAGE_BUFFER_SIZE    512
/**
* @}
*/ 


/** @defgroup USBH_USR_Private_Macros
* @{
*/ 
extern USB_OTG_CORE_HANDLE          USB_OTG_Core;
/**
* @}
*/ 
/** @defgroup USBH_USR_Private_Variables
* @{
*/ 



uint8_t USBH_USR_ApplicationState = USH_USR_FS_INIT;
uint8_t filenameString[15]  = {0};

FATFS fatfs;
FIL file;
uint8_t Image_Buf[IMAGE_BUFFER_SIZE];
uint8_t line_idx = 0;   

/*  Points to the DEVICE_PROP structure of current device */
/*  The purpose of this register is to speed up the execution */

USBH_Usr_cb_TypeDef USRH_cb =
{
  USBH_USR_Init,
  USBH_USR_DeInit,
  USBH_USR_DeviceAttached,
  USBH_USR_ResetDevice,
  USBH_USR_DeviceDisconnected,
  USBH_USR_OverCurrentDetected,
  USBH_USR_DeviceSpeedDetected,
  USBH_USR_Device_DescAvailable,
  USBH_USR_DeviceAddressAssigned,
  USBH_USR_Configuration_DescAvailable,
  USBH_USR_Manufacturer_String,
  USBH_USR_Product_String,
  USBH_USR_SerialNum_String,
  USBH_USR_EnumerationDone,
  USBH_USR_UserInput,
  USBH_USR_MSC_Application,
  USBH_USR_DeviceNotSupported,
  USBH_USR_UnrecoveredError
    
};

/**
* @}
*/

/** @defgroup USBH_USR_Private_Constants
* @{
*/ 
/*--------------- LCD Messages ---------------*/
const uint8_t MSG_HOST_INIT[]        = "> Host Library Initialized\n";
const uint8_t MSG_DEV_ATTACHED[]     = "> Device Attached \n";
const uint8_t MSG_DEV_DISCONNECTED[] = "> Device Disconnected\n";
const uint8_t MSG_DEV_ENUMERATED[]   = "> Enumeration completed \n";
const uint8_t MSG_DEV_HIGHSPEED[]    = "> High speed device detected\n";
const uint8_t MSG_DEV_FULLSPEED[]    = "> Full speed device detected\n";
const uint8_t MSG_DEV_LOWSPEED[]     = "> Low speed device detected\n";
const uint8_t MSG_DEV_ERROR[]        = "> Device fault \n";

const uint8_t MSG_MSC_CLASS[]      = "> Mass storage device connected\n";
const uint8_t MSG_HID_CLASS[]      = "> HID device connected\n";
const uint8_t MSG_DISK_SIZE[]      = "> Size of the disk in MBytes: \n";
const uint8_t MSG_LUN[]            = "> LUN Available in the device:\n";
const uint8_t MSG_ROOT_CONT[]      = "> Exploring disk flash ...\n";
const uint8_t MSG_WR_PROTECT[]      = "> The disk is write protected\n";
const uint8_t MSG_UNREC_ERROR[]     = "> UNRECOVERED ERROR STATE\n";

/**
* @}
*/



/** @defgroup USBH_USR_Private_FunctionPrototypes
* @{
*/
static uint8_t Explore_Disk (char* path , uint8_t recu_level);
static uint8_t Image_Browser (char* path);
static void     Show_Image(void);
static void     Toggle_Leds(void);
/**
* @}
*/ 


/** @defgroup USBH_USR_Private_Functions
* @{
*/ 


/**
* @brief  USBH_USR_Init 
*         Displays the message on LCD for host lib initialization
* @param  None
* @retval None
*/
void USBH_USR_Init(void)
{
  static uint8_t startup = 0;  
  
  if(startup == 0 )
  {
    startup = 1;

    /* Configure the LEDs */
//    STM_EVAL_LEDInit(LED1);
//    STM_EVAL_LEDInit(LED2);
//    STM_EVAL_LEDInit(LED3); 
//    STM_EVAL_LEDInit(LED4); 
    
//    STM_EVAL_PBInit(BUTTON_USER1, BUTTON_MODE_GPIO);
    
#ifdef USE_STM3210C_EVAL
//    STM3210C_LCD_Init();  
#else
//    STM322xG_LCD_Init();
#endif
    
//    LCD_LOG_Init();
      
#ifdef USE_USB_OTG_HS 
//    LCD_LOG_SetHeader(" USB OTG HS MSC Host");
#else
//    LCD_LOG_SetHeader(" USB OTG FS MSC Host");
#endif
//    LCD_UsrLog("> USB Host library started.\n"); 
//    LCD_LOG_SetFooter ("     USB Host Library v2.0.0" );
  }
}

/**
* @brief  USBH_USR_DeviceAttached 
*         Displays the message on LCD on device attached
* @param  None
* @retval None
*/
void USBH_USR_DeviceAttached(void)
{
    printf((void *)MSG_DEV_ATTACHED);
}


/**
* @brief  USBH_USR_UnrecoveredError
* @param  None
* @retval None
*/
void USBH_USR_UnrecoveredError (void)
{
  
  /* Set default screen color*/ 
    printf((void *)MSG_UNREC_ERROR); 
}


/**
* @brief  USBH_DisconnectEvent
*         Device disconnect event
* @param  None
* @retval Staus
*/
void USBH_USR_DeviceDisconnected (void)
{
  
//  LCD_LOG_ClearTextZone();
  
//  LCD_DisplayStringLine( LCD_PIXEL_HEIGHT - 42, "                                   ");
 // LCD_DisplayStringLine( LCD_PIXEL_HEIGHT - 30, "                                   ");  
  
  /* Set default screen color*/
    printf((void *)MSG_DEV_DISCONNECTED);

}
/**
* @brief  USBH_USR_ResetUSBDevice 
* @param  None
* @retval None
*/
void USBH_USR_ResetDevice(void)
{
  /* callback for USB-Reset */
}


/**
* @brief  USBH_USR_DeviceSpeedDetected 
*         Displays the message on LCD for device speed
* @param  Device speed
* @retval None
*/
void USBH_USR_DeviceSpeedDetected(uint8_t DeviceSpeed)
{
  if(DeviceSpeed == HPRT0_PRTSPD_HIGH_SPEED)
  {
      printf((void *)MSG_DEV_HIGHSPEED);
  }  
  else if(DeviceSpeed == HPRT0_PRTSPD_FULL_SPEED)
  {
      printf((void *)MSG_DEV_FULLSPEED);
//	  lcdClear(BLACK);
	  disptp = 1;
//	  printLcdString((void *)MSG_DEV_FULLSPEED,10,10,&font2,BLACK,WHITE,NONE_TRANSPARENT);
  }
  else if(DeviceSpeed == HPRT0_PRTSPD_LOW_SPEED)
  {
      printf((void *)MSG_DEV_LOWSPEED);
  }
  else
  {
      printf((void *)MSG_DEV_ERROR);
  }
}

/**
* @brief  USBH_USR_Device_DescAvailable 
*         Displays the message on LCD for device descriptor
* @param  device descriptor
* @retval None
*/
void USBH_USR_Device_DescAvailable(void *DeviceDesc)
{ 
    USBH_DevDesc_TypeDef *hs;
    hs = DeviceDesc;  
  
	sprintf((char*)displayBuffer,"VID: %04Xh   PID %04Xh",(uint32_t)(*hs).idVendor,(uint32_t)(*hs).idProduct);
	printLcdString(displayBuffer,10,10,&font2,BLACK,WHITE,NONE_TRANSPARENT);
	  
    printf("VID : %04Xh\n\r" , (uint32_t)(*hs).idVendor); 
    printf("PID : %04Xh\n\r" , (uint32_t)(*hs).idProduct); 
}

/**
* @brief  USBH_USR_DeviceAddressAssigned 
*         USB device is successfully assigned the Address 
* @param  None
* @retval None
*/
void USBH_USR_DeviceAddressAssigned(void)
{
  
}


/**
* @brief  USBH_USR_Conf_Desc 
*         Displays the message on LCD for configuration descriptor
* @param  Configuration descriptor
* @retval None
*/
void USBH_USR_Configuration_DescAvailable(USBH_CfgDesc_TypeDef * cfgDesc,
                                          USBH_InterfaceDesc_TypeDef *itfDesc,
                                          USBH_EpDesc_TypeDef *epDesc)
{
  USBH_InterfaceDesc_TypeDef *id;
  
  id = itfDesc;  
  
  if((*id).bInterfaceClass  == 0x08)
  {
      printf((void *)MSG_MSC_CLASS);
  }
  else if((*id).bInterfaceClass  == 0x03)
  {
      printf((void *)MSG_HID_CLASS);
  }    
}

/**
* @brief  USBH_USR_Manufacturer_String 
*         Displays the message on LCD for Manufacturer String 
* @param  Manufacturer String 
* @retval None
*/
void USBH_USR_Manufacturer_String(void *ManufacturerString)
{
    printf("Manufacturer : %s\n\r", (char *)ManufacturerString);
	sprintf((char*)displayBuffer,"Manufacturer : %s",(char *)ManufacturerString);
	printLcdString(displayBuffer,10,30,&font2,BLACK,WHITE,NONE_TRANSPARENT);
}

/**
* @brief  USBH_USR_Product_String 
*         Displays the message on LCD for Product String
* @param  Product String
* @retval None
*/
void USBH_USR_Product_String(void *ProductString)
{
    printf("Product : %s\n\r", (char *)ProductString);
    sprintf((char*)displayBuffer,"Product : %s",(char *)ProductString);
	printLcdString(displayBuffer,10,50,&font2,BLACK,WHITE,NONE_TRANSPARENT);	  
}

/**
* @brief  USBH_USR_SerialNum_String 
*         Displays the message on LCD for SerialNum_String 
* @param  SerialNum_String 
* @retval None
*/
void USBH_USR_SerialNum_String(void *SerialNumString)
{
    printf( "Serial Number : %s\n\r", (char *)SerialNumString);
    sprintf((char*)displayBuffer,"Serial Number : %s",(char *)SerialNumString);
	printLcdString(displayBuffer,10,70,&font2,BLACK,WHITE,NONE_TRANSPARENT);	    
} 



/**
* @brief  EnumerationDone 
*         User response request is displayed to ask application jump to class
* @param  None
* @retval None
*/
void USBH_USR_EnumerationDone(void)
{
  
  /* Enumeration complete */
    printf((void *)MSG_DEV_ENUMERATED);
  
//  LCD_SetTextColor(Green);
//  LCD_DisplayStringLine( LCD_PIXEL_HEIGHT - 42, "To see the root content of the disk : " );
//  LCD_DisplayStringLine( LCD_PIXEL_HEIGHT - 30, "Press USER1...                       ");
//  LCD_SetTextColor(LCD_LOG_DEFAULT_COLOR); 
  
} 


/**
* @brief  USBH_USR_DeviceNotSupported
*         Device is not supported
* @param  None
* @retval None
*/
void USBH_USR_DeviceNotSupported(void)
{
    printf ("> Device not supported.\r\n"); 
}  


/**
* @brief  USBH_USR_UserInput
*         User Action for application state entry
* @param  None
* @retval USBH_USR_Status : User response for USER1 button
*/
USBH_USR_Status USBH_USR_UserInput(void)
{
  USBH_USR_Status usbh_usr_status;
  
  usbh_usr_status = USBH_USR_NO_RESP;  
  
  /*USER1 B3 is in polling mode to detect user action */
//  if(STM_EVAL_PBGetState(BUTTON_USER1) == RESET)
//  if (checkDebouncePressed(0x17) == SET) 
//  {
    
//    usbh_usr_status = USBH_USR_RESP_OK;
    
//  } 
  return usbh_usr_status;
}  

/**
* @brief  USBH_USR_OverCurrentDetected
*         Over Current Detected on VBUS
* @param  None
* @retval Staus
*/
void USBH_USR_OverCurrentDetected (void)
{
    printf ("Overcurrent detected.\r\n");
}


/**
* @brief  USBH_USR_MSC_Application 
*         Demo application for mass storage
* @param  None
* @retval Staus
*/
int USBH_USR_MSC_Application(void)
{
  FRESULT res;
  uint8_t writeTextBuff[] = "free to STM32 Connectivity line Host Demo application using FAT_FS   ";
  
  uint16_t bytesWritten, bytesToWrite;

  switch(USBH_USR_ApplicationState)
  {
  case USH_USR_FS_INIT: 
    
    /* Initialises the File System*/
    if ( f_mount( 0, &fatfs ) != FR_OK ) 
    {
      /* efs initialisation fails*/
      printf("> Cannot initialize File System.\n");
      return(-1);
    }
    printf("> File System initialized.\n\r");
    printf("> Disk capacity :%d Bytes\n\r", USBH_MSC_Param.MSCapacity * \
      USBH_MSC_Param.MSPageLength); 

    printLcdString("> File System initialized",10,90,&font2,BLACK,WHITE,NONE_TRANSPARENT);
    sprintf((char*)displayBuffer,"> Disk capacity : %d KBytes",(USBH_MSC_Param.MSCapacity /1024)*USBH_MSC_Param.MSPageLength); 
	printLcdString(displayBuffer,10,110,&font2,BLACK,WHITE,NONE_TRANSPARENT);	        

    if(USBH_MSC_Param.MSWriteProtect == DISK_WRITE_PROTECTED)
    {
        printf((void *)MSG_WR_PROTECT);
    }
    
    USBH_USR_ApplicationState = USH_USR_FS_READLIST;
    break;
    
  case USH_USR_FS_READLIST:
    
    printf((void *)MSG_ROOT_CONT);
	printLcdString("> Exploring disk flash ...",10,130,&font2,BLACK,WHITE,NONE_TRANSPARENT);
    Explore_Disk("0:/", 1);
    line_idx = 0;   
    USBH_USR_ApplicationState = USH_USR_FS_WRITEFILE;
    
    break;
    
  case USH_USR_FS_WRITEFILE:
    
//    LCD_SetTextColor(Green);
//    LCD_DisplayStringLine( LCD_PIXEL_HEIGHT - 42, "                                              ");
//    LCD_DisplayStringLine( LCD_PIXEL_HEIGHT - 30, "Press USER1 to write file");
//    LCD_SetTextColor(LCD_LOG_DEFAULT_COLOR);
 	
    USB_OTG_BSP_mDelay(100);
    
    /*USER1 B3 in polling*/
    while((HCD_IsDeviceConnected(&USB_OTG_Core))/* && \
//      (STM_EVAL_PBGetState (BUTTON_USER1) == SET))
      (checkDebouncePressed(0x17) == RESET)*/)          
//    {
      Toggle_Leds();
//    }
    
//    lcdClear(BLACK);
    /* Writes a text file, HOSTDEMO.TXT in the disk*/
    printf("> Writing File to disk flash ...\n\r");
	printLcdString("> Writing File to disk flash ...",10,10,&font2,BLACK,WHITE,NONE_TRANSPARENT);
    if(USBH_MSC_Param.MSWriteProtect == DISK_WRITE_PROTECTED)
    {
      
      printf ( "> Disk flash is write protected \n\r");
      USBH_USR_ApplicationState = USH_USR_FS_DRAW;
      break;
    }
    
    /* Register work area for logical drives */
    f_mount(0, &fatfs);
    
    if(f_open(&file, "0:Host-Write-Demo.TXT",FA_CREATE_ALWAYS | FA_WRITE) == FR_OK)
    { 
      /* Write buffer to file */
      bytesToWrite = sizeof(writeTextBuff); 
      res= f_write (&file, writeTextBuff, bytesToWrite, (void *)&bytesWritten);   
      
      if((bytesWritten == 0) || (res != FR_OK)) /*EOF or Error*/
      {
         printf("> Host_Write_Demo.TXT CANNOT be writen.\n\r");
		 printLcdString("> Host_Write_Demo.TXT CANNOT be writen.",10,30,&font2,BLACK,WHITE,NONE_TRANSPARENT);
      }
      else
      {
          printf("> 'Host_Write_Demo.TXT' file created\n\r");
		  printLcdString("> 'Host_Write_Demo.TXT' file created.",10,30,&font2,BLACK,WHITE,NONE_TRANSPARENT);
      }
      
      /*close file and filesystem*/
      f_close(&file);
      f_mount(0, NULL); 
    }
    
    else
    {
        printf ("> Host_Write_Demo.TXT created in the disk\n\n");
    }

    USBH_USR_ApplicationState = USH_USR_FS_DRAW; //ToDo : wait here (continueous PB pressed issue)
    
//    LCD_SetTextColor(Green);
//    LCD_DisplayStringLine( LCD_PIXEL_HEIGHT - 42, "                                              ");
//    LCD_DisplayStringLine( LCD_PIXEL_HEIGHT - 30, "To start Image slide show Press USER1.");
//    LCD_SetTextColor(LCD_LOG_DEFAULT_COLOR); 
    break;
    
  case USH_USR_FS_DRAW:
    
    /*USER1 B3 in polling*/
    while((HCD_IsDeviceConnected(&USB_OTG_Core)) /*&& \
//      (STM_EVAL_PBGetState (BUTTON_USER1) == SET))
    (checkDebouncePressed(0x17) == RESET)*/) 
    {
      Toggle_Leds();
    }
 
    
    while(HCD_IsDeviceConnected(&USB_OTG_Core))
    {
      if ( f_mount( 0, &fatfs ) != FR_OK ) 
      {
        /* fat_fs initialisation fails*/
        return(-1);
      }
      return Image_Browser("0:/");
    }
    break;
  default: break;
  }
  return(0);
}

/**
* @brief  Explore_Disk 
*         Displays disk content
* @param  path: pointer to root path
* @retval None
*/
static uint8_t Explore_Disk (char* path , uint8_t recu_level)
{

  FRESULT res;
  FILINFO fno;
  DIR dir;
  char *fn;
  
#if _USE_LFN
  static char lfn[_MAX_LFN * (_DF1S ? 2 : 1) + 1];
  fno.lfname = lfn;
  fno.lfsize = sizeof(lfn);
#endif
  
  
  res = f_opendir(&dir, path);
  if (res == FR_OK) {
    while(HCD_IsDeviceConnected(&USB_OTG_Core)) 
    {
      res = f_readdir(&dir, &fno);
      if (res != FR_OK || fno.fname[0] == 0) 
      {
        break;
      }
      if (fno.fname[0] == '.')
      {
        continue;
      }
#if _USE_LFN
      fn = *fno.lfname ? fno.lfname : fno.fname;
#else
      fn = fno.fname;
#endif
      

      line_idx++;
      if(line_idx > 9)
      {
        line_idx = 0;
//        LCD_SetTextColor(Green);
//        LCD_DisplayStringLine( LCD_PIXEL_HEIGHT - 42, "                                              ");
//        LCD_DisplayStringLine( LCD_PIXEL_HEIGHT - 30, "Press USER1 to continue...");
//        LCD_SetTextColor(LCD_LOG_DEFAULT_COLOR); 
        
        /*USER1 B3 in polling*/
        while((HCD_IsDeviceConnected(&USB_OTG_Core)) /*&& \
//          (STM_EVAL_PBGetState (BUTTON_USER1) == SET))
        (checkDebouncePressed(0x17) == RESET)*/) 
        {
          Toggle_Leds();
          
        }
      } 
      
      if(recu_level == 1)
      {
          printf("   |__");
      }
      else if(recu_level == 2)
      {
          printf("   |   |__");
      }
      if((fno.fattrib & AM_MASK) == AM_DIR)
      {
          printf((void *)fn);
      }
      else
      {
          printf((void *)fn);
		  printLcdString((void *)fn,10,130+(line_idx*20),&font2,BLACK,RED,NONE_TRANSPARENT);
      }
      printf("\n\r");
      if(((fno.fattrib & AM_MASK) == AM_DIR)&&(recu_level == 1))
      {
        Explore_Disk(fn, 2);
      }
    }
  }
  return res;
}

static uint8_t Image_Browser (char* path)
{
  FRESULT res;
  uint8_t ret = 1;
  FILINFO fno;
  DIR dir;
  char *fn;
#if _USE_LFN
  static char lfn[_MAX_LFN * (_DF1S ? 2 : 1) + 1];
  fno.lfname = lfn;
  fno.lfsize = sizeof(lfn);
#endif
  
  res = f_opendir(&dir, path);
  if (res == FR_OK) {
    
    for (;;) {
      res = f_readdir(&dir, &fno);
      if (res != FR_OK || fno.fname[0] == 0) break;
      if (fno.fname[0] == '.') continue;
#if _USE_LFN
      fn = *fno.lfname ? fno.lfname : fno.fname;
#else
      fn = fno.fname;
#endif
      if (fno.fattrib & AM_DIR) 
      {
        continue;
      } 
      else 
      {
        if((strstr(fn, "bmp")) || (strstr(fn, "BMP")))
        {
          res = f_open(&file, fn, FA_OPEN_EXISTING | FA_READ);
//		  lcdClear(BLACK);
          Show_Image();
          USB_OTG_BSP_mDelay(100);
          ret = 0;
          while((HCD_IsDeviceConnected(&USB_OTG_Core)) /*&& \
//            (STM_EVAL_PBGetState (BUTTON_USER1) == SET))
          (checkDebouncePressed(0x17) == RESET)*/) 
          {
            Toggle_Leds();
          }
          f_close(&file);
//          lcdClear(BLACK);
//	      HDIR_SEGn_SEG0();// ۤ
//	      VDIR_COMn_COM0();// ۤ

        }
      }
    }  
  }
  
  #ifdef USE_USB_OTG_HS 
//  LCD_LOG_SetHeader(" USB OTG HS MSC Host");
#else
//  LCD_LOG_SetHeader(" USB OTG FS MSC Host");
#endif
//  LCD_LOG_SetFooter ("     USB Host Library v2.0.0" );
  printf("> Disk capacity :%d KBytes\n\r", USBH_MSC_Param.MSCapacity/2 
//  * \  USBH_MSC_Param.MSPageLength
  ); 
  USBH_USR_ApplicationState = USH_USR_FS_READLIST;
  return ret;
}

/**
* @brief  Show_Image 
*         Displays BMP image
* @param  None
* @retval None
*/
static void Show_Image(void)
{
  uint16_t i = 0;
  uint16_t numOfReadBytes = 0;
  FRESULT res; 



  /* Bypass Bitmap header */ 
  f_lseek (&file, 54);
//	HDIR_SEG0_SEGn();// ۤ
//	VDIR_COM0_COMn();// ۤ

//    XY_Coordinate(0, 0); // X,Y w /
//	writeCommand(0x02);  
  while (HCD_IsDeviceConnected(&USB_OTG_Core))
  {
    res = f_read(&file, Image_Buf, IMAGE_BUFFER_SIZE, (void *)&numOfReadBytes);
    if((numOfReadBytes == 0) || (res != FR_OK)) /*EOF or Error*/
    {
//      LCD_WriteReg(SSD2119_ENTRY_MODE_REG, ENTRY_MODE_DEFAULT);
		
      break; 
    }
    for(i = 0 ; i < IMAGE_BUFFER_SIZE; i+= 2)
    {
          	    
//	    writeData(Image_Buf[i+1] << 8 | Image_Buf[i]); 
         
    } 
  }

}

/**
* @brief  Toggle_Leds
*         Toggle leds to shows user input state
* @param  None
* @retval None
*/
static void Toggle_Leds(void)
{
  static uint32_t i;
  if (i++ == 0x10000)
  {
//    STM_EVAL_LEDToggle(LED1);
//    STM_EVAL_LEDToggle(LED2);
//    STM_EVAL_LEDToggle(LED3);
//    STM_EVAL_LEDToggle(LED4);
    i = 0;
  }  
}
/**
* @brief  USBH_USR_DeInit
*         Deint User state and associated variables
* @param  None
* @retval None
*/
void USBH_USR_DeInit(void)
{
  USBH_USR_ApplicationState = USH_USR_FS_INIT;
}


/**
* @}
*/ 

/**
* @}
*/ 

/**
* @}
*/

/**
* @}
*/

/******************* (C) COPYRIGHT 2011 STMicroelectronics *****END OF FILE****/






























